@@ -1,20 +1,24 @@
 /*
- * Copyright (c) 2013, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2013, 2018, Oracle and/or its affiliates. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have included with MySQL.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
 #include "mforms/menubar.h"
@@ -165,8 +169,8 @@ mforms::TreeNodeRef CatalogTreeView::create_new_node(const ObjectType &otype, mf
 }
 
 CatalogTreeView::CatalogTreeView(ModelDiagramForm *owner)
-  : mforms::TreeView(mforms::TreeNoBorder | mforms::TreeSizeSmall | mforms::TreeCanBeDragSource | mforms::TreeIndexOnTag
-#ifndef _WIN32
+  : mforms::TreeView(mforms::TreeNoBorder | mforms::TreeCanBeDragSource | mforms::TreeIndexOnTag | mforms::TreeTranslucent
+#ifndef _MSC_VER
                      | mforms::TreeNoHeader
 #endif
                      ),
@@ -176,7 +180,7 @@ CatalogTreeView::CatalogTreeView(ModelDiagramForm *owner)
   _initialized = false;
   bool showHeaderText = true;
   set_selection_mode(mforms::TreeSelectMultiple);
-#ifdef _WIN32
+#ifdef _MSC_VER
   set_row_height(19);
   showHeaderText = false;
 #else
@@ -338,8 +342,14 @@ void CatalogTreeView::context_menu_will_show(mforms::MenuItem *parent_item) {
       }
 
       if (!caption.empty())
-        parent->add_item_with_title(caption, std::bind(&CatalogTreeView::menu_action, this, "edit", value));
+        parent->add_item_with_title(caption, std::bind(&CatalogTreeView::menu_action, this, "edit", value), "", "");
+      else {
+        parent->add_separator();
+      }
+    } else {
+      parent->add_separator();
     }
+
   }
 }
 //--------------------------------------------------------------------------------------------------
