@@ -1,20 +1,24 @@
 /*
- * Copyright (c) 2007, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2018, Oracle and/or its affiliates. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have included with MySQL.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
 #include "wb_overview_diagram.h"
@@ -232,7 +236,7 @@ public:
 
     if (object.is_instance(db_Script::static_class_name())) {
       for (bec::MenuItemList::iterator iter = items.begin(); iter != items.end(); ++iter) {
-        if (iter->name == "plugin:wb.plugin.edit.stored_note") {
+        if (iter->internalName == "plugin:wb.plugin.edit.stored_note") {
           items.erase(iter);
           c--;
           break;
@@ -264,7 +268,8 @@ int SQLScriptsNode::get_popup_menu_items(WBContext *wb, bec::MenuItemList &items
   items.push_back(item);
 
   item.type = bec::MenuAction;
-  item.name = "builtin:add_script_file";
+  item.accessibilityName = "Add Script File";
+  item.internalName = "builtin:add_script_file";
   item.caption = _("Add Script File...");
   items.push_back(item);
 
@@ -331,7 +336,8 @@ int NotesNode::get_popup_menu_items(WBContext *wb, bec::MenuItemList &items) {
   items.push_back(item);
 
   item.type = bec::MenuAction;
-  item.name = "builtin:add_note_file";
+  item.accessibilityName = "Add Note File";
+  item.internalName = "builtin:add_note_file";
   item.caption = _("Add Note File...");
   items.push_back(item);
 
@@ -528,40 +534,42 @@ mforms::MenuBar *PhysicalOverviewBE::get_menubar() {
   if (!_menu) {
     _menu = wb::WBContextUI::get()->get_command_ui()->create_menubar_for_context(WB_CONTEXT_PHYSICAL_OVERVIEW);
 
-    static const char *diagram_only_items[] = {"diagram_size",
-                                               "fnotation",
-                                               "rnotation",
-                                               "wb.edit.goToNextSelected",
-                                               "wb.edit.goToPreviousSelected",
-                                               "wb.edit.selectSimilar",
-                                               "wb.edit.selectConnected",
-                                               "wb.edit.toggleGridAlign",
-                                               "wb.edit.toggleGrid",
-                                               "wb.edit.togglePageGrid",
-                                               "wb.view.zoomDefault",
-                                               "wb.view.zoomIn",
-                                               "wb.view.zoomOut",
-                                               "wb.view.setFigureNotation",
-                                               "wb.view.setRelationshipNotation",
-                                               "wb.view.setMarker:1",
-                                               "wb.view.setMarker:2",
-                                               "wb.view.setMarker:3",
-                                               "wb.view.setMarker:4",
-                                               "wb.view.setMarker:5",
-                                               "wb.view.setMarker:6",
-                                               "wb.view.setMarker:7",
-                                               "wb.view.setMarker:8",
-                                               "wb.view.setMarker:9",
-                                               "wb.view.goToMarker:1",
-                                               "wb.view.goToMarker:2",
-                                               "wb.view.goToMarker:3",
-                                               "wb.view.goToMarker:4",
-                                               "wb.view.goToMarker:5",
-                                               "wb.view.goToMarker:6",
-                                               "wb.view.goToMarker:7",
-                                               "wb.view.goToMarker:8",
-                                               "wb.view.goToMarker:9",
-                                               NULL};
+    static const char *diagram_only_items[] = {
+        "diagram_size",
+        "fnotation",
+        "rnotation",
+        "wb.edit.goToNextSelected",
+        "wb.edit.goToPreviousSelected",
+        "wb.edit.selectSimilar",
+        "wb.edit.selectConnected",
+        "wb.edit.toggleGridAlign",
+        "wb.edit.toggleGrid",
+        "wb.edit.togglePageGrid",
+        "wb.view.zoomDefault",
+        "wb.view.zoomIn",
+        "wb.view.zoomOut",
+        "wb.view.setFigureNotation",
+        "wb.view.setRelationshipNotation",
+        "wb.view.setMarker:1",
+        "wb.view.setMarker:2",
+        "wb.view.setMarker:3",
+        "wb.view.setMarker:4",
+        "wb.view.setMarker:5",
+        "wb.view.setMarker:6",
+        "wb.view.setMarker:7",
+        "wb.view.setMarker:8",
+        "wb.view.setMarker:9",
+        "wb.view.goToMarker:1",
+        "wb.view.goToMarker:2",
+        "wb.view.goToMarker:3",
+        "wb.view.goToMarker:4",
+        "wb.view.goToMarker:5",
+        "wb.view.goToMarker:6",
+        "wb.view.goToMarker:7",
+        "wb.view.goToMarker:8",
+        "wb.view.goToMarker:9",
+        nullptr
+    };
 
     for (int i = 0; diagram_only_items[i]; i++)
       _menu->set_item_enabled(diagram_only_items[i], false);
