@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2019, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
@@ -23,6 +23,8 @@
 
 #pragma once
 
+#include "base/symbol-info.h"
+
 #include "grt.h"
 #include "grt/tree_model.h"
 #include "workbench/wb_backend_public_interface.h"
@@ -35,10 +37,10 @@ namespace wb {
   public:
     friend class LiveSchemaTreeTester;
 
-    static const short COLUMN_DATA = 0x01;
-    static const short TRIGGER_DATA = 0x02;
-    static const short INDEX_DATA = 0x04;
-    static const short FK_DATA = 0x08;
+    static const short COLUMN_DATA;
+    static const short TRIGGER_DATA;
+    static const short INDEX_DATA;
+    static const short FK_DATA;
 
     static const std::string SCHEMA_TAG;
     static const std::string TABLES_TAG;
@@ -370,6 +372,9 @@ namespace wb {
     std::string _active_schema;
     mforms::TreeView* _model_view;
 
+    GPatternSpec* _schema_pattern = nullptr;
+    GPatternSpec* _object_pattern = nullptr;
+
     bool _case_sensitive_identifiers;
 
     void schema_contents_arrived(const std::string& schema_name, base::StringListPtr tables, base::StringListPtr views,
@@ -395,7 +400,7 @@ namespace wb {
     bool is_object_type(ObjectTypeValidation validation, ObjectType type);
 
   public:
-    LiveSchemaTree();
+    LiveSchemaTree(base::MySQLVersion version);
     virtual ~LiveSchemaTree();
 
     void set_model_view(mforms::TreeView* target);
@@ -406,6 +411,8 @@ namespace wb {
                             int fetch_mask);
 
     void set_filter(std::string filter);
+    std::string getFilter() const { return _filter; }
+
     void filter_data();
     void load_data_for_filter(const std::string& schema_filter, const std::string& object_filter);
 
@@ -443,6 +450,8 @@ namespace wb {
       _base = base;
     }
 
+    LiveSchemaTree* getBase() { return _base; }
+
     bool update_node_children(mforms::TreeNodeRef parent, base::StringListPtr children, ObjectType type,
                               bool sorted = false, bool just_append = false);
     void update_change_data(mforms::TreeNodeRef parent, base::StringListPtr children, ObjectType type,
@@ -465,20 +474,22 @@ namespace wb {
     std::string get_schema_name(const mforms::TreeNodeRef& node);
     std::vector<std::string> get_node_path(const mforms::TreeNodeRef& node);
     mforms::TreeNodeRef get_node_from_path(std::vector<std::string> path);
+
     void enable_events(bool enable) {
       _enabled_events = enable;
     }
 
+    bool getEnabledEvents() { return _enabled_events; }
+
   private:
     bool _is_schema_contents_enabled;
     bool _enabled_events;
+    base::MySQLVersion _version;
 
-    LiveSchemaTree* _base;
+    LiveSchemaTree *_base = nullptr;
     std::string _filter;
     ObjectType _filter_type;
-    GPatternSpec* _schema_pattern;
-    GPatternSpec* _object_pattern;
-    LSTData* notify_on_reload_data;
+    LSTData *notify_on_reload_data = nullptr;
 
     static const char* _schema_tokens[16];
 
