@@ -1,24 +1,29 @@
 /*
- * Copyright (c) 2013, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2013, 2018, Oracle and/or its affiliates. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have included with MySQL.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
-#ifndef __wb_sql_editor_result_tab__
-#define __wb_sql_editor_result_tab__
+#pragma once
+
+#include "base/notifications.h"
 
 #include "workbench/wb_backend_public_interface.h"
 
@@ -41,11 +46,12 @@ namespace mforms {
   class ContextMenu;
   class TreeView;
   class GridView;
+  class ScrollPanel;
 };
 
 class ResultFormView;
 
-class MYSQLWBBACKEND_PUBLIC_FUNC SqlEditorResult : public mforms::AppView {
+class MYSQLWBBACKEND_PUBLIC_FUNC SqlEditorResult : public mforms::AppView, public base::Observer {
   SqlEditorPanel *_owner;
   Recordset::Ptr _rset;
 
@@ -115,6 +121,7 @@ private:
 
   mforms::AppView *_column_info_box;
   mforms::AppView *_query_stats_box;
+  mforms::ScrollPanel *_query_stats_panel;
   mforms::AppView *_resultset_placeholder;
   mforms::AppView *_execution_plan_placeholder;
   ResultFormView *_form_result_view;
@@ -137,6 +144,9 @@ private:
 
   bool _pinned;
 
+  void handle_notification(const std::string &name, void *sender, base::NotificationInfo &info);
+  void updateColors();
+
   void update_selection_for_menu_extra(mforms::ContextMenu *menu, const std::vector<int> &rows, int column);
   void switch_tab();
 
@@ -165,5 +175,3 @@ private:
   void on_recordset_column_resized(int column);
   void onRecordsetColumnsResized(const std::vector<int> cols);
 };
-
-#endif /* __wb_sql_editor_result_tab__ */
