@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2007, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2019, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
@@ -314,7 +314,7 @@ bool ModelFile::attempt_xml_document_upgrade(xmlDocPtr xmldoc, const std::string
         }
       }
 
-      xml.traverse_subtree("/physicalModels/0/catalog/schemata/0/tables", std::ptr_fun(fix_user_datatypes));
+      xml.traverse_subtree("/physicalModels/0/catalog/schemata/0/tables",  std::bind(&fix_user_datatypes, std::placeholders::_1, std::placeholders::_2));
 
       // add boolean UDT to the userTypes list
       typesList = xml.get_object_by_path("/physicalModels/0/catalog/userDatatypes");
