@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2007, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2019, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
@@ -109,6 +109,7 @@ DbConnectPanel::DbConnectPanel(DbConnectPanelFlags flags)
 
   _name_entry.set_name("Connection Name");
   _name_entry.setInternalName("connect_panel:table");
+  _table.set_name("Connection information");
   _table.set_row_count(flags & DbConnectPanelShowRDBMSCombo ? 4 : 2);
   _table.set_column_count(3);
 
@@ -144,7 +145,7 @@ DbConnectPanel::DbConnectPanel(DbConnectPanelFlags flags)
   _table.add(&_driver_sel, 1, 2, row, row + 1, mforms::HExpandFlag | mforms::HFillFlag | mforms::VFillFlag);
   _table.add(&_desc3, 2, 3, row, row + 1, mforms::HFillFlag);
 
-  _tab.set_name("Connection");
+  _tab.set_name("Connection Details");
   _params_panel.set_name("Parameters");
   _ssl_panel.set_name("SSL");
   _advanced_panel.set_name("Advanced");
@@ -565,24 +566,16 @@ void DbConnectPanel::save_connection_as(const std::string &name) {
   db_mgmt_ConnectionRef conn(_connection->get_connection());
 
   grt::ListRef<db_mgmt_Connection> list(_connection->get_db_mgmt()->storedConns());
-  if (list.get_index(conn) != grt::BaseListRef::npos)
-    throw std::invalid_argument("The connection cannot be saved because it is already stored");
 
   db_mgmt_ConnectionRef dup;
   if ((dup = find_named_object_in_list(list, name, true, "name")).is_valid()) {
     list->remove(dup);
-    // throw std::invalid_argument(strfmt("The connection cannot be saved. There already is a connection named '%s'",
-    // name.c_str()));
   }
 
   list = _connection->get_db_mgmt()->otherStoredConns();
-  if (list.get_index(conn) != grt::BaseListRef::npos)
-    throw std::invalid_argument("The connection cannot be saved because it is already stored");
 
   if ((dup = find_named_object_in_list(list, name, true, "name")).is_valid()) {
     list->remove(dup);
-    // throw std::invalid_argument(strfmt("The connection cannot be saved. There already is a connection named '%s'",
-    // name.c_str()));
   }
 
   conn->name(name);
@@ -623,8 +616,8 @@ bool DbConnectPanel::test_connection() {
         // check that we're connecting to a known and supported version of the server
         std::string version;
         {
-          std::auto_ptr<sql::Statement> stmt(_dbc_conn->createStatement());
-          std::auto_ptr<sql::ResultSet> result(stmt->executeQuery("SELECT version()"));
+          std::unique_ptr<sql::Statement> stmt(_dbc_conn->createStatement());
+          std::unique_ptr<sql::ResultSet> result(stmt->executeQuery("SELECT version()"));
           if (result->next())
             version = result->getString(1);
         }
@@ -646,8 +639,8 @@ bool DbConnectPanel::test_connection() {
 
         // check ssl
         {
-          std::auto_ptr<sql::Statement> stmt(_dbc_conn->createStatement());
-          std::auto_ptr<sql::ResultSet> result(stmt->executeQuery("SHOW SESSION STATUS LIKE 'Ssl_cipher'"));
+          std::unique_ptr<sql::Statement> stmt(_dbc_conn->createStatement());
+          std::unique_ptr<sql::ResultSet> result(stmt->executeQuery("SHOW SESSION STATUS LIKE 'Ssl_cipher'"));
           if (result->next())
             ssl_cipher = result->getString(2);
 
@@ -1137,6 +1130,24 @@ void DbConnectPanel::create_control(::DbDriverParam *driver_param, const ::Contr
       _views.push_back(ctrl);
       break;
     }
+    case ::ctDirSelector: {
+      FsObjectSelector *ctrl = new FsObjectSelector();
+      ctrl->set_name(driver_param->get_accessibility_name());
+      ctrl->setInternalName(driver_param->get_control_name());
+      // value
+      grt::StringRef value = driver_param->get_value_repr();
+      std::string initial_value = "";
+      if (value.is_valid())
+        initial_value = *value;
+
+      ctrl->set_size(bounds.width, -1);
+
+      ctrl->initialize(initial_value, mforms::OpenDirectory, "", true,
+                       std::bind(&DbConnectPanel::param_value_changed, this, ctrl, true));
+      box->add(mforms::manage(ctrl), true, true);
+      _views.push_back(ctrl);
+      break;
+    }
     case ::ctEnumSelector: {
       mforms::Selector *ctrl = new Selector();
       ctrl->set_name(driver_param->get_accessibility_name());
