@@ -1,20 +1,24 @@
 /*
- * Copyright (c) 2007, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2018, Oracle and/or its affiliates. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have included with MySQL.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
 #include <grts/structs.db.h>
@@ -26,6 +30,8 @@
 #include "grt/common.h"
 #include "grtdb/db_object_helpers.h"
 
+#include "grtsqlparser/mysql_parser_services.h"
+
 using namespace base;
 
 //================================================================================
@@ -152,9 +158,6 @@ grt::StringRef db_Column::formattedType() const {
 void db_Column::formattedType(const grt::StringRef &value) {
   if (formattedType() == value.c_str())
     return;
-  // add code here
-  g_warning("got a request to change %s.formattedType() from '%s' to '%s'",
-            owner().is_valid() ? owner()->name().c_str() : "<null>", formattedType().c_str(), value.c_str());
 }
 
 /** Sets the datatype defined by a string to the column.
@@ -171,11 +174,11 @@ grt::IntegerRef db_Column::setParseType(const std::string &type, const grt::List
     db_CatalogRef catalog = db_CatalogRef::cast_from(owner()->owner()->owner());
     user_types = catalog->userDatatypes();
     default_type_list = catalog->simpleDatatypes();
-    GrtVersionRef catalogVersion = catalog->version();
+    GrtVersionRef catalogVersion = GrtVersionRef::cast_from(bec::getModelOption(workbench_physical_ModelRef::cast_from(catalog->owner()), "CatalogVersion"));
     targetVersion->majorNumber(catalogVersion->majorNumber());
     targetVersion->minorNumber(catalogVersion->minorNumber());
     targetVersion->releaseNumber(catalogVersion->releaseNumber() > 0 ? catalogVersion->releaseNumber()
-                                                                     : grt::IntegerRef(999));
+                                                                     : grt::IntegerRef(99));
     targetVersion->buildNumber(catalogVersion->buildNumber());
     targetVersion->status(catalogVersion->status());
   }
@@ -188,10 +191,11 @@ grt::IntegerRef db_Column::setParseType(const std::string &type, const grt::List
   std::string datatypeExplicitParams;
   grt::AutoUndo undo(!is_global());
 
-  // if the available release number is negative, that's meant to signify "any release number",
-  if (!bec::parse_type_definition(type, targetVersion, typeList, user_types, default_type_list, simpleType, userType,
-                                  precision, scale, length, datatypeExplicitParams))
-    return 0;
+  // If the available release number is negative, that's meant to signify "any release number".
+  parsers::MySQLParserServices *services = parsers::MySQLParserServices::get();
+  if (!services->parseTypeDefinition(type, targetVersion, typeList, user_types, default_type_list,
+      simpleType, userType, precision, scale, length, datatypeExplicitParams))
+      return 0;
   this->userType(userType);
   this->simpleType(simpleType);
   this->precision(precision);
