@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2010, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2010, 2019, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
@@ -409,7 +409,7 @@ void WbContext::set_create_main_form_view(MySQL::Workbench::WbFrontendCallbacks
   VOID_STR_UIFORM_CB cb = static_cast<VOID_STR_UIFORM_CB>(ip.ToPointer());
 
   ::wb::WBFrontendCallbacks *callbacks = cbacks->get_callbacks();
-  callbacks->create_main_form_view = std::ptr_fun(cb);
+  callbacks->create_main_form_view = cb;
 }
 
 //--------------------------------------------------------------------------------------------------
