@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2007, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2019, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
@@ -237,7 +237,7 @@ PreferencesForm::PreferencesForm(const workbench_physical_ModelRef &model)
     _font_list(mforms::TreeFlatList) {
   _model = model;
 
-  set_name("Preferences");
+  set_name("Workbench Preferences");
   setInternalName("preferences");
 
   if (!model.is_valid())
