@@ -1,20 +1,24 @@
 /*
- * Copyright (c) 2009, 2015, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2018, Oracle and/or its affiliates. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have included with MySQL.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
 #import "MOutlineView.h"
@@ -41,8 +45,8 @@ static void refresh_tree(const bec::NodeId &node, int ocount, void *tree)
 - (std::vector<bec::NodeId>)selectedNodeIds
 {
   std::vector<bec::NodeId> nodes;
-  NSIndexSet *iset= [self selectedRowIndexes];
-  NSUInteger index = [iset firstIndex];
+  NSIndexSet *iset= self.selectedRowIndexes;
+  NSUInteger index = iset.firstIndex;
   while (index != NSNotFound)
   {
     nodes.push_back([[self itemAtRow: index] nodeId]);
@@ -77,7 +81,7 @@ static void refresh_tree(const bec::NodeId &node, int ocount, void *tree)
   {
     bec::TreeModel *model = [self getTreeModel];
     if (model)
-      model->tree_changed_signal()->connect(boost::bind(refresh_tree, _1, _2, (__bridge void *)self));
+      model->tree_changed_signal()->connect(std::bind(refresh_tree, std::placeholders::_1, std::placeholders::_2, (__bridge void *)self));
     mConnectedRefresh= YES;
   }
 }
@@ -105,10 +109,10 @@ static void refresh_tree(const bec::NodeId &node, int ocount, void *tree)
       NSMenuItem *item= [menu addItemWithTitle: [NSString stringWithCPPString: iter->caption]
                                           action: itemAction
                                    keyEquivalent: @""];
-      [item setTarget: self];
+      item.target = self;
       if (!iter->enabled)
         [item setEnabled: NO];
-      [item setRepresentedObject: [NSString stringWithCPPString: iter->name]];
+      item.representedObject = [NSString stringWithCPPString: iter->internalName];
       
       if (iter->type == bec::MenuCascade)
       {
@@ -116,7 +120,7 @@ static void refresh_tree(const bec::NodeId &node, int ocount, void *tree)
         {
           NSMenu *submenu= [[NSMenu alloc] initWithTitle: @""];
           [self fillMenu: submenu withItems:iter->subitems selector:@selector(activateMenuItem:)];
-          [item setSubmenu: submenu];
+          item.submenu = submenu;
         }
       }
     }
@@ -158,7 +162,7 @@ static void refresh_tree(const bec::NodeId &node, int ocount, void *tree)
 
 - (void)rightMouseDown:(NSEvent *)theEvent
 {
-  [self selectRowIndexes: [NSIndexSet indexSetWithIndex: [self rowAtPoint: [self convertPoint: [theEvent locationInWindow] fromView: nil]]]
+  [self selectRowIndexes: [NSIndexSet indexSetWithIndex: [self rowAtPoint: [self convertPoint: theEvent.locationInWindow fromView: nil]]]
     byExtendingSelection: NO];
   [super rightMouseDown: theEvent];
 }
