@@ -1,20 +1,24 @@
-/* 
- * Copyright (c) 2009, 2015, Oracle and/or its affiliates. All rights reserved.
+/*
+ * Copyright (c) 2009, 2018, Oracle and/or its affiliates. All rights reserved.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
+ *
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have included with MySQL.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
- * 
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- * 
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
 #import "mforms/app.h"
@@ -50,14 +54,7 @@
   [[NSNotificationCenter defaultCenter] removeObserver: self];
 }
 
-
-- (bec::GRTManager*)grtManager
-{
-  return _grtm;
-}
-
-
-- (id)identifier
+- (id)panelId
 {
   return nil;
 }
@@ -65,7 +62,7 @@
 
 - (NSString*)title
 {
-  bec::BaseEditor *ed = [self editorBE];
+  bec::BaseEditor *ed = self.editorBE;
   if (ed)
     return [NSString stringWithCPPString: ed->get_title()];
   return nil;
@@ -88,12 +85,12 @@
   if (mApplyButton && mRevertButton)
   {
     [mApplyButton setHidden: NO];
-    [mApplyButton setTarget: self];
-    [mApplyButton setAction: @selector(applyLiveChanges:)];
+    mApplyButton.target = self;
+    mApplyButton.action = @selector(applyLiveChanges:);
 
     [mRevertButton setHidden: NO];
-    [mRevertButton setTarget: self];
-    [mRevertButton setAction: @selector(revertLiveChanges:)];
+    mRevertButton.target = self;
+    mRevertButton.action = @selector(revertLiveChanges:);
   }
   return NO;
 }
@@ -106,20 +103,20 @@
 - (void)notifyObjectSwitched
 {
   if (mEditorGRTObject.is_valid())
-    mEditorGRTObject->get_data()->notify_did_switch_object([self editorBE]);
+    mEditorGRTObject->get_data()->notify_did_switch_object(self.editorBE);
 }
 
 
 - (void)updateTitle:(NSString*)title
 {
-  id superview = [[self view] superview];
+  id superview = self.view.superview;
   if ([superview isKindOfClass: [NSTabView class]])
   {
     NSTabView *tabView= (NSTabView*)superview;
     // workaround for stupid tabview hack
-    if ([[tabView superview] isKindOfClass: [WBTabView class]])
-      tabView = (NSTabView*)[tabView superview];
-    NSInteger index = [tabView indexOfTabViewItemWithIdentifier: [self identifier]];
+    if ([tabView.superview isKindOfClass: [WBTabView class]])
+      tabView = (NSTabView*)tabView.superview;
+    NSInteger index = [tabView indexOfTabViewItemWithIdentifier: self.panelId];
     if (index != NSNotFound)
     {
       id item= [tabView tabViewItemAtIndex: index];
@@ -159,9 +156,9 @@
 - (void)applyLiveChanges:(id)sender
 {
   // set focus to nothing to force ongoing text changes to be commited
-  [[[self view] window] makeFirstResponder: nil];
+  [self.view.window makeFirstResponder: nil];
 
-  bec::BaseEditor *editor = [self editorBE];
+  bec::BaseEditor *editor = self.editorBE;
   if (editor && editor->is_editing_live_object())
   {
     if (mEditorGRTObject.is_valid())
@@ -173,9 +170,9 @@
 - (void)revertLiveChanges:(id)sender
 {
   // set focus to nothing to force ongoing text changes to be commited
-  [[[self view] window] makeFirstResponder: nil];
+  [self.view.window makeFirstResponder: nil];
 
-  bec::BaseEditor *editor = [self editorBE];
+  bec::BaseEditor *editor = self.editorBE;
   if (editor && editor->is_editing_live_object())
   {
     editor->revert_changes_to_live_object();
@@ -194,21 +191,21 @@
 - (BOOL)pluginWillClose: (id)sender
 {
   // set focus to nothing to force ongoing text changes to be commited
-  [[[self view] window] makeFirstResponder: nil];
+  [self.view.window makeFirstResponder: nil];
 
   if (mEditorGRTObject.is_valid())
     if (!mEditorGRTObject->get_data()->notify_will_close())
       return NO;
 
-  bec::BaseEditor *editor = [self editorBE];
+  bec::BaseEditor *editor = self.editorBE;
   if (editor && !editor->can_close())
     return NO;
   
   // by default, we check if the firstResponder belongs to this plugin and make it
   // resign so that edits are commited
-  id first= [[[self view] window] firstResponder];
-  id dockableView= [self view];
-  NSWindow *window= [[self view] window];
+  id first= self.view.window.firstResponder;
+  id dockableView= self.view;
+  NSWindow *window= self.view.window;
   
   while (first && first != dockableView && first != window)
     first= [first superview];
@@ -224,18 +221,18 @@
 static void text_changed(int line, int linesAdded, void *editor_)
 {
   WBPluginEditorBase *editor = (__bridge WBPluginEditorBase*)editor_;
-  bool dirty = [editor editorBE]->get_sql_editor()->get_editor_control()->is_dirty();
-  if ([editor->mApplyButton isEnabled] != dirty)
-    [editor updateTitle: [editor title]];
-  [editor->mApplyButton setEnabled: dirty];
-  [editor->mRevertButton setEnabled: dirty];
+  bool dirty = editor.editorBE->get_sql_editor()->get_editor_control()->is_dirty();
+  if (editor->mApplyButton.enabled != dirty)
+    [editor updateTitle: editor.title];
+  editor->mApplyButton.enabled = dirty;
+  editor->mRevertButton.enabled = dirty;
 }
 
 //--------------------------------------------------------------------------------------------------
 
 - (void)setupEditorOnHost: (NSView*)host
 {
-  MySQLEditor::Ref backend_editor = [self editorBE]->get_sql_editor();
+  MySQLEditor::Ref backend_editor = self.editorBE->get_sql_editor();
   mforms::CodeEditor* mforms_editor = backend_editor->get_editor_control();
   mforms_editor->set_status_text("");
 
@@ -247,31 +244,32 @@ static void text_changed(int line, int linesAdded, void *editor_)
                                                name: NSTextDidEndEditingNotification
                                              object: nsviewForView(mforms_editor)];
 
-  std::string font = grt::StringRef::cast_from([self editorBE]->get_grt_manager()->get_app_option("workbench.general.Editor:Font"));
+
+  std::string font = grt::StringRef::cast_from(bec::GRTManager::get()->get_app_option("workbench.general.Editor:Font"));
   mforms_editor->set_font(font); 
 
-  mforms_editor->signal_changed()->connect(boost::bind(text_changed, _1, _2, (__bridge void *)self));
+  mforms_editor->signal_changed()->connect(std::bind(text_changed, std::placeholders::_1, std::placeholders::_2, (__bridge void *)self));
 
-  for (id subview in [[host subviews] reverseObjectEnumerator])
+  for (id subview in [host.subviews reverseObjectEnumerator])
   {
     [subview removeFromSuperview];
   }
   [host addSubview: container];
-  [container setFrame: [host bounds]];
+  container.frame = host.bounds;
   [host setAutoresizesSubviews: YES];
-  [container setAutoresizingMask: NSViewWidthSizable | NSViewHeightSizable];
+  container.autoresizingMask = NSViewWidthSizable | NSViewHeightSizable;
 }
 
 //--------------------------------------------------------------------------------------------------
 
 - (void)enablePluginDocking:(NSTabView*)tabView
 {
-  mEditorGRTObject = ui_ObjectEditorRef(_grtm->get_grt());
+  mEditorGRTObject = ui_ObjectEditorRef(grt::Initialized);
 
   // setup docking point for mUpperTabView
   mDockingPoint = mforms::manage(new mforms::DockingPoint(new TabViewDockingPointDelegate(tabView, "editor"), true));
 
-  mEditorGRTObject->dockingPoint(mforms_to_grt(_grtm->get_grt(), mDockingPoint));
+  mEditorGRTObject->dockingPoint(mforms_to_grt(mDockingPoint));
 }
 
 @end
