@@ -1,20 +1,24 @@
-/* 
- * Copyright (c) 2009, 2017, Oracle and/or its affiliates. All rights reserved.
+/*
+ * Copyright (c) 2009, 2018, Oracle and/or its affiliates. All rights reserved.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
+ *
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have included with MySQL.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
- * 
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- * 
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
 #import "MResultsetViewer.h"
@@ -159,7 +163,7 @@ static const char *viewFlagsKey = "viewFlagsKey";
     alert.messageText = @"Too Many Columns";
     alert.informativeText = @"The resultset for your query contains too many columns, which may be very slow to display."
       "\nHowever, as a workaround, manual resizing of columns can be disabled to speed up display and scrolling.";
-    alert.alertStyle = NSWarningAlertStyle;
+    alert.alertStyle = NSAlertStyleWarning;
     [alert addButtonWithTitle: @"Disable Column Resizing"];
     [alert addButtonWithTitle: @"Ignore"];
 
@@ -451,7 +455,7 @@ static int onRefresh(void *viewer)
     forTableColumn: (NSTableColumn*) aTableColumn
                row: (NSInteger) rowIndex;
 {
-  if (aTableColumn.identifier && ![[aTableColumn identifier] isEqualToString: @""])
+  if (aTableColumn.identifier && ![aTableColumn.identifier isEqualToString: @""])
   {
     int columnIndex = aTableColumn.identifier.intValue;    
     
