@@ -1,19 +1,25 @@
-/* 
- * Copyright (c) 2008, 2016, Oracle and/or its affiliates. All rights reserved.
- * 
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; version 2 of the License.
+/*
+ * Copyright (c) 2008, 2018, Oracle and/or its affiliates. All rights reserved.
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
-
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have included with MySQL.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
+ */
 
 #import "WBMenuManager.h"
 #import "MCPPUtilities.h"
@@ -48,7 +54,7 @@
       item.enabled = iter->enabled?YES:NO;
       item.target = target;
       [menu addItem: item];
-      item.representedObject = [NSString stringWithCPPString: iter->name];
+      item.representedObject = [NSString stringWithCPPString: iter->internalName];
 
       if (iter->type == bec::MenuCascade)
       {
@@ -64,7 +70,7 @@
     else if (iter->type == bec::MenuSeparator)
       [menu addItem: [NSMenuItem separatorItem]];
     else
-      NSLog(@"unknown context menu item type in %s", iter->name.c_str());
+      NSLog(@"unknown context menu item type in %s", iter->internalName.c_str());
   }
   
   for (NSInteger i= oldCount - 1; i >= 0; i--)
