@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2019, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
@@ -639,6 +639,12 @@ static void expandVertically(std::vector<ChildEntry> &list, int fraction, bool m
 
 //----------------------------------------------------------------------------------------------------------------------
 
+- (NSAccessibilityRole)accessibilityRole {
+  return NSAccessibilityGroupRole;
+}
+
+//----------------------------------------------------------------------------------------------------------------------
+
 static bool box_create(::mforms::Box *self, bool horiz) {
   MFBoxImpl *box = [[MFBoxImpl alloc] initWithObject: self];
 
