@@ -1,20 +1,24 @@
 /*
- * Copyright (c) 2009, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2018, Oracle and/or its affiliates. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have included with MySQL.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
 #include "mforms/view.h"
@@ -76,10 +80,27 @@
       [super mouseUp:event];                                 \
   }
 
-#define STANDARD_FOCUS_HANDLING(wrapper) \
-  -(BOOL)becomeFirstResponder {          \
-    wrapper->mOwner->focus_changed();    \
-    return [super becomeFirstResponder]; \
+#define STANDARD_FOCUS_HANDLING(wrapper)                     \
+  -(BOOL)becomeFirstResponder {                              \
+    wrapper->mOwner->focus_changed();                        \
+    if (![self handleBecomeFirstResponder: wrapper->mOwner]) \
+      return [super becomeFirstResponder];                   \
+    return NO;                                               \
+  }                                                          \
+  -(BOOL)resignFirstResponder {                              \
+    if (![self handleResignFirstResponder: wrapper->mOwner]) \
+      return [super resignFirstResponder];                   \
+    return NO;                                               \
+  }
+
+#define STANDARD_KEYBOARD_HANDLING(wrapper)                 \
+  -(void)keyUp : (NSEvent *)event {                         \
+    if (![self handleKeyUp: event owner:wrapper->mOwner])   \
+      return [super keyUp:event];                           \
+  }                                                         \
+  -(void)keyDown : (NSEvent *)event {                       \
+    if (![self handleKeyDown: event owner:wrapper->mOwner]) \
+      return [super keyDown:event];                         \
   }
 
 enum ViewFlags {
@@ -122,6 +143,10 @@ namespace mforms {
 - (bool)handleMouseMove:(NSEvent *)event owner:(mforms::View *)mOwner;
 - (bool)handleMouseEntered:(NSEvent *)event owner:(mforms::View *)mOwner;
 - (bool)handleMouseExited:(NSEvent *)event owner:(mforms::View *)mOwner;
+- (bool)handleBecomeFirstResponder:(mforms::View *)mOwner;
+- (bool)handleResignFirstResponder:(mforms::View *)mOwner;
+- (bool)handleKeyUp:(NSEvent *)event owner:(mforms::View *)mOwner;
+- (bool)handleKeyDown:(NSEvent *)event owner:(mforms::View *)mOwner;
 - (NSTrackingArea *)updateTrackingArea:(NSTrackingArea *)currentArea;
 
 - (NSSize)preferredSize:(NSSize)proposal;
