@@ -1,25 +1,29 @@
 /*
- * Copyright (c) 2007, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2018, Oracle and/or its affiliates. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have included with MySQL.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
 #pragma once
 
-#ifndef _WIN32
+#ifndef _MSC_VER
 
 #include <glib.h>
 #include <list>
@@ -52,7 +56,7 @@
 
 #include "mdc_canvas_public.h"
 
-#ifdef _WIN32
+#ifdef _MSC_VER
 #define DEFAULT_FONT_FACE "Arial"
 #elif defined(__APPLE__)
 #define DEFAULT_FONT_FACE "Lucida Grande"
@@ -184,7 +188,7 @@ namespace mdc {
     void save_to_png(const std::string &destination) const;
   };
 
-#ifdef _WIN32
+#ifdef _MSC_VER
   class MYSQLCANVAS_PUBLIC_FUNC Win32Surface : public Surface {
   public:
     Win32Surface(HDC hdc, bool printing = false);
