@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2007, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2019, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
@@ -67,7 +67,7 @@ public:
     _limit_ins_pos = limit_ins_pos;
     _statement_valid = false;
 
-    _process_sql_statement = boost::bind(&Mysql_sql_statement_info::process_sql_statement, this, _1);
+    _process_sql_statement = boost::bind(&Mysql_sql_statement_info::process_sql_statement, this, boost::placeholders::_1);
 
     Mysql_sql_parser_fe sql_parser_fe(bec::GRTManager::get()->get_app_option_string("SqlMode"));
     sql_parser_fe.ignore_dml = false;
@@ -270,7 +270,7 @@ std::string blob_to_string_(const unsigned char *data, size_t size) {
 }
 
 sqlide::QuoteVar::Blob_to_string Mysql_sql_specifics::blob_to_string() {
-  return std::ptr_fun(&blob_to_string_);
+  return blob_to_string_;
 }
 
 std::string Mysql_sql_specifics::setting_non_std_sql_delimiter() {
