@@ -1,20 +1,24 @@
-/* 
- * Copyright (c) 2009, 2015, Oracle and/or its affiliates. All rights reserved.
+/*
+ * Copyright (c) 2009, 2018, Oracle and/or its affiliates. All rights reserved.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
+ *
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have included with MySQL.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
- * 
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- * 
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
 #include "base/geometry.h"
@@ -49,13 +53,11 @@ static void call_refresh(void *theEditor)
 
 
 - (instancetype)initWithModule: (grt::Module*)module
-                    grtManager: (bec::GRTManager *)grtm
                      arguments: (const grt::BaseListRef &)args
 {
   self= [super initWithNibName: @"MySQLRoutineEditor"  bundle: [NSBundle bundleForClass:[self class]]];
   if (self != nil)
   {
-    _grtm = grtm;
     // load GUI. Top level view in the nib is the NSTabView that will be docked to the main window
     [self loadView];
 
@@ -76,19 +78,19 @@ static void call_refresh(void *theEditor)
   delete mBackEnd;
   
     // setup the editor backend with the schema object (args[0])
-  mBackEnd = new MySQLRoutineEditorBE(_grtm, db_mysql_RoutineRef::cast_from(args[0]));
+  mBackEnd = new MySQLRoutineEditorBE(db_mysql_RoutineRef::cast_from(args[0]));
   
   // register a callback that will make [self refresh] get called
   // whenever the backend thinks its needed to refresh the UI from the backend data (ie, the
   // edited object was changed from somewhere else in the application)
-  mBackEnd->set_refresh_ui_slot(boost::bind(call_refresh, (__bridge void *)self));
+  mBackEnd->set_refresh_ui_slot(std::bind(call_refresh, (__bridge void *)self));
   
   [self setupEditorOnHost: editorHost];
   mBackEnd->load_routine_sql();
 
   if (mBackEnd->is_editing_live_object())
   {
-    int i = [tabView indexOfTabViewItemWithIdentifier: @"comments"];
+    NSInteger i = [tabView indexOfTabViewItemWithIdentifier: @"comments"];
     if (i > 0)
       [tabView removeTabViewItem: [tabView tabViewItemAtIndex: i]];
     commentText = nil;
@@ -124,7 +126,7 @@ static void call_refresh(void *theEditor)
   }
 }
 
-- (id)identifier
+- (id)panelId
 {
   // an identifier for this editor (just take the object id)
   return [NSString stringWithCPPString:mBackEnd->get_object().id()];
