@@ -1,20 +1,24 @@
 /*
- * Copyright (c) 2012, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have included with MySQL.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
 #ifndef _NAME_MAPPING_EDITOR_H_
@@ -55,7 +59,7 @@ public:
       _tree(mforms::TreeShowColumnLines | mforms::TreeAltRowColors),
       _bbox(true) {
     set_title(_("Table Name Mapping"));
-    set_name("table_name_mapping_editor");
+    set_name("Table Name Mapping Editor");
 
     _vbox.add(&_heading, false, true);
     _heading.set_text(
@@ -312,7 +316,7 @@ public:
       _tree(mforms::TreeShowColumnLines | mforms::TreeAltRowColors),
       _bbox(true) {
     set_title(_("Column Name Mapping"));
-    set_name("column_name_mapping_editor");
+    set_name("Column Name Mapping Editor");
 
     _vbox.add(&_heading, false, true);
     _heading.set_text(
