@@ -1,23 +1,27 @@
 /*
- * Copyright (c) 2016, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2016, 2021, Oracle and/or its affiliates. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have included with MySQL.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
-#ifdef _WIN32
+#ifdef _MSC_VER
 #define HAVE_ROUND
 #endif
 
@@ -73,9 +77,9 @@ bool PythonCopyDataSource::pystring_to_string(PyObject *strobject, std::string &
   if (PyUnicode_Check(strobject)) {
     PyObject *ref = PyUnicode_AsUTF8String(strobject);
     if (ref) {
-      char *s;
+      const char *s;
       Py_ssize_t len;
-      PyString_AsStringAndSize(ref, &s, &len);
+      s = PyUnicode_AsUTF8AndSize(ref, &len);
       if (s)
         ret_string = std::string(s, len);
       else
@@ -86,10 +90,10 @@ bool PythonCopyDataSource::pystring_to_string(PyObject *strobject, std::string &
     return false;
   }
 
-  if (PyString_Check(strobject)) {
-    char *s;
+  if (PyUnicode_Check(strobject)) {
+    const char *s;
     Py_ssize_t len;
-    PyString_AsStringAndSize(strobject, &s, &len);
+    s = PyUnicode_AsUTF8AndSize(strobject, &len);
     if (s)
       ret_string = std::string(s, len);
     else
@@ -141,7 +145,7 @@ void PythonCopyDataSource::_init() // This has to be executed from the same thre
   }
 
   if (pConnectFunction && PyCallable_Check(pConnectFunction)) {
-    if (PyUnicode_Check(params) || PyString_Check(params)) {
+    if (PyUnicode_Check(params) || PyUnicode_Check(params)) {
       PyObject *connection_arg = PyTuple_Pack(1, params);
       _connection = PyObject_CallObject(pConnectFunction, connection_arg);
       Py_DECREF(connection_arg);
@@ -258,7 +262,7 @@ size_t PythonCopyDataSource::count_rows(const std::string &schema, const std::st
   }
 
   PyObject *element = PySequence_GetItem(row, 0);
-  size_t count = (size_t)PyInt_AsUnsignedLongLongMask(element);
+  size_t count = (size_t)PyLong_AsUnsignedLongLongMask(element);
   Py_DECREF(element);
   Py_DECREF(row);
 
@@ -411,11 +415,11 @@ bool PythonCopyDataSource::fetch_row(RowBuffer &rowbuffer) {
           PyGILState_Release(state);
           return false;
         }
-      } else if (!PyBuffer_Check(element)) // Old-style buffers are the interface specified in PEP 249 for BLOB data.
-                                           // Attempt to convert.
+      } else if (!PyObject_CheckBuffer(element)) // Old-style buffers are the interface specified in PEP 249 for BLOB data.
+                                                 // Attempt to convert.
       {
         PyObject *element_copy = element;
-        element = PyBuffer_FromObject(element, 0, Py_END_OF_BUFFER);
+        // element = PyBuffer_FromObject(element, 0, Py_END_OF_BUFFER); // FIXME: WL-12709 fix buffer
         Py_DECREF(element_copy);
         if (PyErr_Occurred()) {
           PyErr_Print();
@@ -426,56 +430,59 @@ bool PythonCopyDataSource::fetch_row(RowBuffer &rowbuffer) {
           return false;
         }
       }
-      const char *blob_read_buffer;
-      Py_ssize_t blob_read_buffer_len;
-      int res = PyObject_AsReadBuffer(element, (const void **)&blob_read_buffer, &blob_read_buffer_len);
+      Py_buffer view;
+      //Py_ssize_t blob_read_buffer_len;
+      int res = PyObject_GetBuffer(element, &view, PyBUF_SIMPLE);
       if (res != 0) {
-        if (PyErr_Occurred())
+        if (PyErr_Occurred()) {
           PyErr_Print();
+        }
         logError("Could not get a read buffer for the BLOB column %s.%s. Skipping table!\n", _table_name.c_str(),
                  (*_columns)[i].source_name.c_str());
         Py_DECREF(element);
         PyGILState_Release(state);
         return false;
       }
-      if (blob_read_buffer_len > _max_parameter_size) {
+      if (view.len > _max_parameter_size) {
         if (_abort_on_oversized_blobs) {
+
           PyGILState_Release(state);
           throw std::runtime_error(base::strfmt("oversized blob found in table %s.%s, size: %lu", _schema_name.c_str(),
-                                                _table_name.c_str(), (long unsigned int)blob_read_buffer_len));
+                                                _table_name.c_str(), (long unsigned int)view.len));
+          PyBuffer_Release(&view);
         } else {
           logError("Oversized blob found in table %s.%s, size: %lu", _schema_name.c_str(), _table_name.c_str(),
-                   (long unsigned int)blob_read_buffer_len);
+                   (long unsigned int)view.len);
           rowbuffer.finish_field(true);
           Py_DECREF(element);
+          PyBuffer_Release(&view);
           continue;
         }
-      } else // Proceed to copy from the buffer
-      {
+      } else { // Proceed to copy from the buffer
         Py_ssize_t copied_bytes = 0;
-        if (!blob_read_buffer_len) // empty buffer
-        {
-          rowbuffer[i].buffer_length = *rowbuffer[i].length = (unsigned long)blob_read_buffer_len;
-          rowbuffer[i].buffer = NULL;
+        if (!view.len) { // empty buffer
+          rowbuffer[i].buffer_length = *rowbuffer[i].length = (unsigned long)view.len;
+          rowbuffer[i].buffer = nullptr;
         }
-        while (copied_bytes < blob_read_buffer_len) {
-          Py_ssize_t this_pass_size = std::min(blob_read_buffer_len - copied_bytes, (Py_ssize_t)_max_blob_chunk_size);
+        while (copied_bytes < view.len) {
+          Py_ssize_t this_pass_size = std::min(view.len - copied_bytes, (Py_ssize_t)_max_blob_chunk_size);
           // ---- Begin Section: This will fail if multiple passes are done. TODO: Fix this.
           if (_use_bulk_inserts) {
             if (rowbuffer[i].buffer_length)
               free(rowbuffer[i].buffer);
 
-            *rowbuffer[i].length = (unsigned long)blob_read_buffer_len;
-            rowbuffer[i].buffer_length = (unsigned long)blob_read_buffer_len;
-            rowbuffer[i].buffer = malloc(blob_read_buffer_len);
+            *rowbuffer[i].length = (unsigned long)view.len;
+            rowbuffer[i].buffer_length = (unsigned long)view.len;
+            rowbuffer[i].buffer = malloc(view.len);
 
-            memcpy(rowbuffer[i].buffer, blob_read_buffer, blob_read_buffer_len);
+            memcpy(rowbuffer[i].buffer, view.buf, view.len);
           } else
-            rowbuffer.send_blob_data(blob_read_buffer + copied_bytes, this_pass_size);
+            rowbuffer.send_blob_data((const char*)view.buf + copied_bytes, this_pass_size);
           // ---- End Section
-          copied_bytes += this_pass_size;
+          copied_bytes += this_pass_size;         
         }
         rowbuffer.finish_field(false);
+        PyBuffer_Release(&view);
         Py_DECREF(element);
         continue;
       }
@@ -488,9 +495,9 @@ bool PythonCopyDataSource::fetch_row(RowBuffer &rowbuffer) {
         rowbuffer.prepare_add_tiny(buffer, buffer_len);
         if (!was_null) {
           if (is_unsigned)
-            *((unsigned char *)buffer) = (unsigned char)PyInt_AsLong(element);
+            *((unsigned char *)buffer) = (unsigned char)PyLong_AsLong(element);
           else
-            *buffer = (char)PyInt_AsLong(element);
+            *buffer = (char)PyLong_AsLong(element);
         }
         rowbuffer.finish_field(was_null);
         break;
@@ -499,9 +506,9 @@ bool PythonCopyDataSource::fetch_row(RowBuffer &rowbuffer) {
         rowbuffer.prepare_add_short(buffer, buffer_len);
         if (!was_null) {
           if (is_unsigned)
-            *((unsigned short *)buffer) = (unsigned short)PyInt_AsLong(element);
+            *((unsigned short *)buffer) = (unsigned short)PyLong_AsLong(element);
           else
-            *((short *)buffer) = (short)PyInt_AsLong(element);
+            *((short *)buffer) = (short)PyLong_AsLong(element);
         }
         rowbuffer.finish_field(was_null);
         break;
@@ -510,9 +517,9 @@ bool PythonCopyDataSource::fetch_row(RowBuffer &rowbuffer) {
         rowbuffer.prepare_add_long(buffer, buffer_len);
         if (!was_null) {
           if (is_unsigned)
-            *((unsigned long *)buffer) = PyInt_AsUnsignedLongMask(element);
+            *((unsigned long *)buffer) = PyLong_AsUnsignedLongMask(element);
           else
-            *((long *)buffer) = PyInt_AsLong(element);
+            *((long *)buffer) = PyLong_AsLong(element);
         }
         rowbuffer.finish_field(was_null);
         break;
@@ -521,7 +528,7 @@ bool PythonCopyDataSource::fetch_row(RowBuffer &rowbuffer) {
         if (!was_null) {
           if (is_unsigned)
             *((unsigned long long *)buffer) =
-              PyInt_Check(element) ? PyInt_AsUnsignedLongLongMask(element) : PyLong_AsUnsignedLongLong(element);
+              PyLong_Check(element) ? PyLong_AsUnsignedLongLongMask(element) : PyLong_AsUnsignedLongLong(element);
           else
             *((long long *)buffer) = PyLong_AsLongLong(element);
         }
@@ -558,7 +565,7 @@ bool PythonCopyDataSource::fetch_row(RowBuffer &rowbuffer) {
             Py_DECREF(old_ref);
           }
           if (PyUnicode_Check(element) ||
-              PyString_Check(element)) // element is a string (sqlite sends time data as strings)
+              PyUnicode_Check(element)) // element is a string (sqlite sends time data as strings)
           {
             std::string elem_str;
             pystring_to_string(element, elem_str);
@@ -584,7 +591,7 @@ bool PythonCopyDataSource::fetch_row(RowBuffer &rowbuffer) {
         if (!was_null) {
           // Target type can be MYSQL_TYPE_STRING for decimal columns and yet values can be ints or floats
           // If that's the case, get str(element) for insertion:
-          if (PyFloat_Check(element) || PyInt_Check(element) || PyLong_Check(element)) {
+          if (PyFloat_Check(element) || PyLong_Check(element) || PyLong_Check(element)) {
             PyObject *elem_ref = element;
             element = PyObject_Str(element);
             Py_DECREF(elem_ref);
@@ -593,9 +600,9 @@ bool PythonCopyDataSource::fetch_row(RowBuffer &rowbuffer) {
           if (PyUnicode_Check(element)) {
             PyObject *ref = PyUnicode_AsUTF8String(element);
             if (ref) {
-              char *s;
+              const char *s;
               Py_ssize_t len;
-              PyString_AsStringAndSize(ref, &s, &len);
+              s = PyUnicode_AsUTF8AndSize(ref, &len);
               if (buffer_len < (size_t)len) {
                 logError("Truncating data in column %s from %lul to %lul. Possible loss of data.\n",
                          (*_columns)[i].source_name.c_str(), (long unsigned int)len, (long unsigned int)buffer_len);
@@ -609,10 +616,10 @@ bool PythonCopyDataSource::fetch_row(RowBuffer &rowbuffer) {
               PyGILState_Release(state);
               return false;
             }
-          } else if (PyString_Check(element)) {
-            char *s;
+          } else if (PyUnicode_Check(element)) {
+            const char *s;
             Py_ssize_t len;
-            PyString_AsStringAndSize(element, &s, &len);
+            s = PyUnicode_AsUTF8AndSize(element, &len);
             if (buffer_len < (size_t)len) {
               logError("Truncating data in column %s from %lul to %lul. Possible loss of data.\n",
                        (*_columns)[i].source_name.c_str(), (long unsigned int)len, (long unsigned int)buffer_len);
