@@ -1,19 +1,23 @@
-# Copyright (c) 2012, 2016, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2012, 2020, Oracle and/or its affiliates.
 #
-# This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License as
-# published by the Free Software Foundation; version 2 of the
-# License.
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License, version 2.0,
+# as published by the Free Software Foundation.
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
+# This program is also distributed with certain software (including
+# but not limited to OpenSSL) that is licensed under separate terms, as
+# designated in a particular file or component or in included license
+# documentation.  The authors of MySQL hereby grant you an additional
+# permission to link the program and your derivative works with the
+# separately licensed software that they have included with MySQL.
+# This program is distributed in the hope that it will be useful,  but
+# WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+# the GNU General Public License, version 2.0, for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-# 02110-1301  USA
+# along with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 
 import sys
 import grt
@@ -29,46 +33,53 @@ class SetupMainView(WizardPage):
     def _browse_files(self, option, title):
         form = mforms.newFileChooser(mforms.Form.main_form(), mforms.SaveFile)
         form.set_title(title)
-        form.set_path(getattr(self, option+"_entry").get_string_value())
+        ctrl_name = option.replace(" ", "")
+        form.set_path(getattr(self, ctrl_name + "_entry").get_string_value())
         if form.run_modal():
-            getattr(self, option+"_entry").set_value(form.get_path())
-            setattr(self, option+"_check_duplicate", False)
+            getattr(self, ctrl_name + "_entry").set_value(form.get_path())
+            setattr(self, ctrl_name + "_check_duplicate", False)
 
     def _add_script_radiobutton_option(self, box, name, caption, path_caption, browser_caption, label_caption, rid):
+        ctrl_name = name.replace(" ", "")
         holder = mforms.newBox(False)
         holder.set_spacing(4)
         radio = mforms.newRadioButton(rid)
         radio.set_text(caption)
+        radio.set_name("%s Option" % name)
         holder.add(radio, False, True)
         vbox = mforms.newBox(False)
         vbox.set_spacing(4)
         file_box = mforms.newBox(True)
         file_box.set_spacing(4)
-        file_box.add(mforms.newLabel(path_caption), False, True)
+        path_label = mforms.newLabel(path_caption)
+        path_label.set_name(name)
+        file_box.add(path_label, False, True)
         file_entry = mforms.newTextEntry()
-        file_entry.add_changed_callback(lambda self=self, option=name: setattr(self, name+"_check_duplicate", True))
+        file_entry.set_name(name + " Value")
+        file_entry.add_changed_callback(lambda self=self, option=name: setattr(self, ctrl_name + "_check_duplicate", True))
         file_box.add(file_entry, True, True)
         radio.add_clicked_callback(self._script_radio_option_callback)
         button = mforms.newButton()
         button.set_text("Browse...")
+        button.set_name("Browse")
         button.add_clicked_callback(lambda option=name, title=browser_caption: self._browse_files(option, title))
         file_box.add(button, False, True)
         vbox.add(file_box, False, True)
         label = mforms.newLabel(label_caption)
+        label.set_name(name + " Help")
         label.set_style(mforms.SmallHelpTextStyle)
         vbox.add(label, False, True)
         vbox.set_enabled(False)
         holder.add(vbox, False, True)
         box.add(holder, False, True)
-
-        setattr(self, name+"_check_duplicate", False)
-        setattr(self, name+"_radiobutton", radio)
-        setattr(self, name+"_entry", file_entry)
-        setattr(self, name+"_vbox", vbox)
+        setattr(self, ctrl_name + "_check_duplicate", False)
+        setattr(self, ctrl_name + "_radiobutton", radio)
+        setattr(self, ctrl_name + "_entry", file_entry)
+        setattr(self, ctrl_name + "_vbox", vbox)
 
     def _script_radio_option_callback(self):
-        self.copy_script_vbox.set_enabled(self.copy_script_radiobutton.get_active())
-        self.bulk_copy_script_vbox.set_enabled(self.bulk_copy_script_radiobutton.get_active())
+        self.CopyScript_vbox.set_enabled(self.CopyScript_radiobutton.get_active())
+        self.BulkCopyScript_vbox.set_enabled(self.BulkCopyScript_radiobutton.get_active())
 
     def __init__(self, main):
         WizardPage.__init__(self, main, "Data Transfer Setup")
@@ -76,6 +87,7 @@ class SetupMainView(WizardPage):
         self.main.add_wizard_page(self, "DataMigration", "Data Transfer Setup")
 
         label = mforms.newLabel("Select options for the copy of the migrated schema tables in the target MySQL server and click [Next >] to execute.")
+        label.set_name("Page Description")
         self.content.add(label, False, True)
 
         panel = mforms.newPanel(mforms.TitledBoxPanel)
@@ -91,6 +103,7 @@ class SetupMainView(WizardPage):
 
         self._copy_db = mforms.newRadioButton(rid)
         self._copy_db.set_text("Online copy of table data to target RDBMS")
+        self._copy_db.set_name("Online Copy")
         self._copy_db.add_clicked_callback(self._script_radio_option_callback)
         box.add(self._copy_db, False, True)
 
@@ -99,11 +112,11 @@ class SetupMainView(WizardPage):
         #self._add_script_checkbox_option(box, "dump_to_file", "Create a dump file with the data", "Dump File:", "Save As")
 
         if sys.platform == "win32":
-            self._add_script_radiobutton_option(box, "copy_script", "Create a batch file to copy the data at another time", "Batch File:", "Save As", "You should edit this file to add the source and target server passwords before running it.", rid)
+            self._add_script_radiobutton_option(box, "Copy Script", "Create a batch file to copy the data at another time", "Batch File:", "Save As", "You should edit this file to add the source and target server passwords before running it.", rid)
         else:
-            self._add_script_radiobutton_option(box, "copy_script", "Create a shell script to copy the data from outside Workbench", "Shell Script File:", "Save As", "You should edit this file to add the source and target server passwords before running it.", rid)
+            self._add_script_radiobutton_option(box, "Copy Script", "Create a shell script to copy the data from outside Workbench", "Shell Script File:", "Save As", "You should edit this file to add the source and target server passwords before running it.", rid)
 
-        self._add_script_radiobutton_option(box, "bulk_copy_script", "Create a shell script to use native server dump and load abilities for fast migration", "Bulk Data Copy Script:", "Save As", "Edit the generated file and change passwords at the top of the generated script.\nRun it on the source server to create a zip package containing a data dump as well as a load script.\nCopy this to the target server, extract it, and run the import script. See the script output for further details.", rid)
+        self._add_script_radiobutton_option(box, "Bulk Copy Script", "Create a shell script to use native server dump and load abilities for fast migration", "Bulk Data Copy Script:", "Save As", "Edit the generated file and change passwords at the top of the generated script.\nRun it on the source server to create a zip package containing a data dump as well as a load script.\nCopy this to the target server, extract it, and run the import script. See the script output for further details.", rid)
 
         panel = mforms.newPanel(mforms.TitledBoxPanel)
         panel.set_title("Options")
@@ -116,12 +129,16 @@ class SetupMainView(WizardPage):
 
         self._truncate_db = mforms.newCheckBox()
         self._truncate_db.set_text("Truncate target tables (i.e. delete contents) before copying data")
+        self._truncate_db.set_name("Truncate")
         self.options_box.add(self._truncate_db, False, True)
 
         hbox = mforms.newBox(True)
         hbox.set_spacing(16)
-        hbox.add(mforms.newLabel("Worker tasks"), False, True)
+        worker_label = mforms.newLabel("Worker tasks")
+        worker_label.set_name("Worker Tasks")
+        hbox.add(worker_label, False, True)
         self._worker_count = mforms.newTextEntry()
+        self._worker_count.set_name("Worker Tasks Count")
         self._worker_count.set_value("2")
         self._worker_count.set_size(30, -1)
         hbox.add(self._worker_count, False, True)
@@ -134,7 +151,13 @@ class SetupMainView(WizardPage):
 
         self._debug_copy = mforms.newCheckBox()
         self._debug_copy.set_text("Enable debug output for table copy")
+        self._debug_copy.set_name("Enable Debug Output")
         self.options_box.add(self._debug_copy, False, True)
+        
+        self._driver_sends_utf8 = mforms.newCheckBox()
+        self._driver_sends_utf8.set_text("Driver sends data already encoded as UTF-8.")
+        self._driver_sends_utf8.set_name("Send UTF8 Data")
+        self.options_box.add(self._driver_sends_utf8, False, True)
 
 
         ###
@@ -150,10 +173,11 @@ class SetupMainView(WizardPage):
         l = mforms.newLabel("""You can limit the number of rows to be copied for certain tables. Tables that are referenced by
 foreign keys from other tables cannot be limited, unless data copy from the referencing tables is also disabled.
 All tables are copied by default.""")
+        l.set_name("Description")
         l.set_style(mforms.SmallHelpTextStyle)
         box.add(l, False, True)
 
-        self._tree = mforms.newTreeNodeView(mforms.TreeDefault)
+        self._tree = mforms.newTreeView(mforms.TreeDefault)
         self._tree.add_column(mforms.IconStringColumnType, "Table", 200, False)
         self._tree.add_column(mforms.StringColumnType, "Limit Copy", 100, True)
         self._tree.add_column(mforms.StringColumnType, "Referencing Tables", 500, False)
@@ -182,23 +206,24 @@ All tables are copied by default.""")
         #    if "GenerateDumpScript" in self.main.plan.state.dataBulkTransferParams:
         #       del self.main.plan.state.dataBulkTransferParams["GenerateDumpScript"]
 
-        if self.copy_script_radiobutton.get_active():
-            self.main.plan.state.dataBulkTransferParams["GenerateCopyScript"] = self.copy_script_entry.get_string_value()
+        if self.CopyScript_radiobutton.get_active():
+            self.main.plan.state.dataBulkTransferParams["GenerateCopyScript"] = self.CopyScript_entry.get_string_value()
         else:
-            if self.main.plan.state.dataBulkTransferParams.has_key("GenerateCopyScript"):
+            if self.main.plan.state.dataBulkTransferParams.get("GenerateCopyScript", False):
                 del self.main.plan.state.dataBulkTransferParams["GenerateCopyScript"]
 
-        if self.bulk_copy_script_radiobutton.get_active():
-            self.main.plan.state.dataBulkTransferParams["GenerateBulkCopyScript"] = self.bulk_copy_script_entry.get_string_value()
+        if self.BulkCopyScript_radiobutton.get_active():
+            self.main.plan.state.dataBulkTransferParams["GenerateBulkCopyScript"] = self.BulkCopyScript_entry.get_string_value()
         else:
-            if self.main.plan.state.dataBulkTransferParams.has_key("GenerateBulkCopyScript"):
+            if self.main.plan.state.dataBulkTransferParams.get("GenerateBulkCopyScript", False):
                 del self.main.plan.state.dataBulkTransferParams["GenerateBulkCopyScript"]
 
         self.main.plan.state.dataBulkTransferParams["LiveDataCopy"] = 1 if self._copy_db.get_active() else 0
         self.main.plan.state.dataBulkTransferParams["DebugTableCopy"] = 1 if self._debug_copy.get_active() else 0
+        self.main.plan.state.dataBulkTransferParams["DriverSendsDataAsUTF8"] = 1 if self._driver_sends_utf8.get_active() else 0
         self.main.plan.state.dataBulkTransferParams["TruncateTargetTables"] = 1 if self._truncate_db.get_active() else 0
 
-        for key in self.main.plan.state.dataBulkTransferParams.keys():
+        for key in list(self.main.plan.state.dataBulkTransferParams.keys()):
             if key.endswith(":rangeKey"):
                 del self.main.plan.state.dataBulkTransferParams[key]
             if key.endswith(":rangeStart"):
@@ -227,7 +252,7 @@ All tables are copied by default.""")
 
         self.main.plan.state.dataBulkTransferParams["tableList"] = tables_to_copy
 
-        if self._copy_db.get_active() or self.copy_script_radiobutton.get_active() or self.bulk_copy_script_radiobutton.get_active():
+        if self.main.plan.state.dataBulkTransferParams["tableList"]:
             return WizardPage.go_next(self)
         else:
             self.main.go_next_page(2)
@@ -251,7 +276,7 @@ All tables are copied by default.""")
                 self._copy_db.set_active(False)
 
             self.refresh_table_list()
-            for k in self.main.plan.state.dataBulkTransferParams.keys():
+            for k in list(self.main.plan.state.dataBulkTransferParams.keys()):
                 del self.main.plan.state.dataBulkTransferParams[k]
 
 
@@ -259,20 +284,20 @@ All tables are copied by default.""")
                 filename = mforms.Utilities.get_special_folder(mforms.Desktop)+"\\copy_migrated_tables.cmd"
             else:
                 filename = mforms.Utilities.get_special_folder(mforms.Desktop)+"/copy_migrated_tables.sh"
-            self.copy_script_entry.set_value(filename)
-            self.copy_script_check_duplicate = True
+            self.CopyScript_entry.set_value(filename)
+            self.CopyScript_check_duplicate = True
 
             source_os = self.main.plan.migrationSource.get_os()
             if not source_os:
-                self.bulk_copy_script_radiobutton.set_enabled(False)
+                self.BulkCopyScript_radiobutton.set_enabled(False)
                 bulk_copy_filename = ''
                 grt.send_warning('Cannot get operating system of source server.')
             elif source_os == "windows":
                 bulk_copy_filename = os.path.join(mforms.Utilities.get_special_folder(mforms.Desktop), 'bulk_copy_tables.cmd')
             else:
                 bulk_copy_filename = os.path.join(mforms.Utilities.get_special_folder(mforms.Desktop), 'bulk_copy_tables.sh')
-            self.bulk_copy_script_entry.set_value(bulk_copy_filename)
-            self.bulk_copy_script_check_duplicate = True
+            self.BulkCopyScript_entry.set_value(bulk_copy_filename)
+            self.BulkCopyScript_check_duplicate = True
 
 
         WizardPage.page_activated(self, advancing)
@@ -365,9 +390,9 @@ class TransferMainView(WizardProgressPage):
 
         self.retry_box = mforms.newBox(True)
         self.content.remove(self._detail_label)
-        self.retry_box.add(self._detail_label, True, True)
+        self.retry_box.add(self._detail_label, False, True)
         self.retry_box.add(self.retry_button, False, True)
-        self.content.add(self.retry_box, False, False)
+        self.content.add(self.retry_box, False, True)
         self.retry_button.show(False)
 
         self.main.add_wizard_page(self, "DataMigration", "Bulk Data Transfer")
@@ -375,21 +400,21 @@ class TransferMainView(WizardProgressPage):
         self._tables_to_exclude = list()
 
     def page_activated(self, advancing):
-        if advancing:
+        if advancing and self.main.plan.state.dataBulkTransferParams["tableList"]:
             options = self.main.plan.state.dataBulkTransferParams
             copy_script = options.get("GenerateCopyScript", None)
             bulk_copy_script = options.get("GenerateBulkCopyScript", None)
 
-            self.add_task(self._prepare_copy, "Prepare information for data copy")
+            self.add_task(self._prepare_copy, "Prepare information for data copy", "Prepare Information for Data Copy")
             if copy_script != None:
-                self._copy_script_task = self.add_task(self._create_copy_script, "Create shell script for data copy")
+                self._copy_script_task = self.add_task(self._create_copy_script, "Create shell script for data copy", "Create Shell Script for Data Copy")
 
             if bulk_copy_script != None:
-                self._bulk_copy_script_task = self.add_task(self._create_bulk_copy_script, "Create shell script for bulk data copy")
+                self._bulk_copy_script_task = self.add_task(self._create_bulk_copy_script, "Create shell script for bulk data copy", "Create Shell Script for Bulk Data Copy")
 
             if options.get("LiveDataCopy", False) or options.get("GenerateDumpScript", False):
-                self._migrate_task1 = self.add_threaded_task(self._count_rows, "Determine number of rows to copy")
-                self._migrate_task2 = self.add_threaded_task(self._migrate_data, "Copy data to target RDBMS")
+                self._migrate_task1 = self.add_threaded_task(self._count_rows, "Determine number of rows to copy", "Determine number of rows to copy")
+                self._migrate_task2 = self.add_threaded_task(self._migrate_data, "Copy data to target RDBMS", "Copy data to target RDBMS")
 
             self._migrating_data = False
             self._progress_per_table = {}
@@ -413,7 +438,7 @@ class TransferMainView(WizardProgressPage):
                           self.main.plan.migrationSource.connection, source_password,
                           self.main.plan.migrationTarget.connection, target_password)
 
-            self._transferer.copytable_path = self.main.plan.wbcopytables_path
+            self._transferer.copytable_path = self.main.plan.wbcopytables_path_bin
         WizardProgressPage.page_activated(self, advancing)
 
 
@@ -436,6 +461,10 @@ class TransferMainView(WizardProgressPage):
 
         source_db_module = self.main.plan.migrationSource.module_db()
         target_db_module = self.main.plan.migrationTarget.module_db()
+        ttimeout = str(self.main.plan.migrationTarget.connection.parameterValues['timeout'])
+        stimeout = ''
+        if 'timeout' in self.main.plan.migrationSource.connection.parameterValues:
+            stimeout = str(self.main.plan.migrationSource.connection.parameterValues['timeout'])
 
         self._working_set = {}
         for table in tables:
@@ -475,7 +504,7 @@ class TransferMainView(WizardProgressPage):
             self._working_set[schema_name+"."+table_name] = {"table" : table,
                         "source_schema":schema_name, "source_table":table_name,
                         "target_schema":targ_schema_name, "target_table":targ_table_name,
-                        "target_table_object":table}
+                        "target_table_object":table, "ttimeout":ttimeout, "stimeout":stimeout}
             select_expression = []
             source_pk_list = []
             target_pk_list = []
@@ -510,7 +539,7 @@ class TransferMainView(WizardProgressPage):
             def cmt(s):
                 return "REM "+s+"\n"
         else:
-            os.chmod(path, 0700)
+            os.chmod(path, 0o700)
             def cmt(s):
                 return "# "+s+"\n"
             f.write("#!/bin/sh\n")
@@ -531,10 +560,28 @@ class TransferMainView(WizardProgressPage):
             f.write("REM Source and target DB passwords\n")
             f.write("set arg_source_password=\n")
             f.write("set arg_target_password=\n")
+            f.write("set arg_source_ssh_password=\n")
+            f.write("set arg_target_ssh_password=\n")
+            f.write("\n")
             f.write("""
+REM Set the location for wbcopytables.exe in this variable
+set "wbcopytables_path=""" + os.getcwd() + """"
+
+if not [%wbcopytables_path%] == [] set wbcopytables_path=%wbcopytables_path%
+set wbcopytables=%wbcopytables_path%\\wbcopytables.exe
+
+if not exist "%wbcopytables%" (
+	echo "wbcopytables.exe doesn't exist in the supplied path. Please set 'wbcopytables_path' with the proper path(e.g. to Workbench binaries)"
+	exit 1
+)
+
 IF [%arg_source_password%] == [] (
     IF [%arg_target_password%] == [] (
-        ECHO WARNING: Both source and target RDBMSes passwords are empty. You should edit this file to set them.
+        IF [%arg_source_ssh_password%] == [] (
+            IF [%arg_target_ssh_password%] == [] (
+                ECHO WARNING: All source and target passwords are empty. You should edit this file to set them.
+            )
+        )
     )
 )
 """)
@@ -551,11 +598,11 @@ IF [%arg_source_password%] == [] (
             f.write("REM Creation of file with table definitions for copytable\n\n")
 
             # Creates a temporary file name with the tables to be migrated
-            filename = '"%TMP%\wb_tables_to_migrate.txt"'
+            filename = '%TMP%\wb_tables_to_migrate.txt'
             f.write("set table_file=%s\n" % filename)
             f.write("TYPE NUL > %s\n" % filename)
 
-            for table in self._working_set.values():
+            for table in list(self._working_set.values()):
                 fields = []
                 fields.append(table["source_schema"])
                 fields.append(table["source_table"])
@@ -569,11 +616,15 @@ IF [%arg_source_password%] == [] (
                 f.write(line + "\n")
 
             f.write("\n\n")
-            f.write(self.main.plan.wbcopytables_path)
-            for arg in self._transferer.helper_basic_arglist(True):
-                f.write(' %s' % arg)
-            f.write(' --source-password="%arg_source_password%" --target-password="%arg_target_password%" --table-file="%table_file%"')
-            f.write(' --thread-count=%arg_worker_count% %arg_truncate_target% %arg_debug_output%')
+            f.write("\"%wbcopytables%\"")
+            f.write(" ^\n")
+            for arg in self._transferer.helper_basic_arglist(True, True):
+                f.write(' %s ^\n' % arg)
+            f.write(' --source-password="%arg_source_password%" ^\n --target-password="%arg_target_password%" ^\n --table-file="%table_file%" ^\n')
+            for arg in self._transferer.helper_ssh_arglist(True):
+                f.write(' %s ^\n' % arg)
+            f.write(' --source-ssh-password="%arg_source_ssh_password%" ^\n --target-ssh-password="%arg_target_ssh_password%"')
+            f.write(' --thread-count=%arg_worker_count% ^\n %arg_truncate_target% ^\n %arg_debug_output%')
             f.write("\n\n")
             f.write("REM Removes the file with the table definitions\n")
             f.write("DEL %s\n" % filename)
@@ -581,9 +632,11 @@ IF [%arg_source_password%] == [] (
             f.write("# Source and target DB passwords\n")
             f.write("arg_source_password=\n")
             f.write("arg_target_password=\n")
+            f.write("arg_source_ssh_password=\n")
+            f.write("arg_target_ssh_password=\n")
             f.write("""
-if [ -z "$arg_source_password" ] && [ -z "$arg_target_password" ] ; then
-    echo WARNING: Both source and target RDBMSes passwords are empty. You should edit this file to set them.
+if [ -z "$arg_source_password" ] && [ -z "$arg_target_password" ] && [ -z "$arg_source_ssh_password" ] && [ -z "$arg_target_ssh_password" ] ; then
+    echo WARNING: All source and target passwords are empty. You should edit this file to set them.
 fi
 """)
             f.write("arg_worker_count=%d\n" % worker_count)
@@ -597,12 +650,17 @@ fi
             f.write( ("" if debug_table_copy else "# ") + "arg_debug_output=--log-level=debug3\n")
             f.write("\n")
             f.write(self.main.plan.wbcopytables_path)
-            for arg in self._transferer.helper_basic_arglist(True):
-                f.write(' %s' % arg)
-            f.write(' --source-password="$arg_source_password" --target-password="$arg_target_password"')
-            f.write(' --thread-count=$arg_worker_count $arg_truncate_target $arg_debug_output')
+            f.write(" \\\n")           
+            for arg in self._transferer.helper_basic_arglist(True, True):
+                f.write(' %s \\\n' % arg)
+            f.write(' --source-password="$arg_source_password" \\\n --target-password="$arg_target_password" \\\n')
+            for arg in self._transferer.helper_ssh_arglist(True):
+                f.write(' %s \\\n' % arg)
+            f.write(' --source-ssh-password="$arg_source_ssh_password" \\\n --target-ssh-password="$arg_target_ssh_password" \\\n')
 
-            for table in self._working_set.values():
+            f.write(' --thread-count=$arg_worker_count \\\n $arg_truncate_target \\\n $arg_debug_output \\\n')
+
+            for table in list(self._working_set.values()):
                 opt = "--table '%s' '%s' '%s' '%s' '%s' '%s' '%s'" % (table["source_schema"], 
                                                                       table["source_table"], 
                                                                       table["target_schema"], 
@@ -629,7 +687,7 @@ fi
         target_os = self.main.plan.migrationTarget.get_os()
 
         script = DataCopyFactory(source_os, target_os, conn_args['source_rdbms'])
-        script.generate(self._working_set.values(), conn_args, script_path)
+        script.generate(list(self._working_set.values()), conn_args, script_path)
 
 
 
@@ -638,7 +696,7 @@ fi
         total = self._transferer.count_table_rows(self._working_set)
 
         self.send_info("%i total rows in %i tables need to be copied:" % (total, len(self._working_set)))
-        for task in self._working_set.values():
+        for task in list(self._working_set.values()):
             self.send_info("- %s.%s: %s" % (task["source_schema"], task["source_table"], task.get("row_count", "error")))
 
 
@@ -646,7 +704,7 @@ fi
         # update the label with the number of rows to copy here, since this is in the main thread
         total = 0
         table_count = len (self._working_set);
-        for task in self._working_set.values():
+        for task in list(self._working_set.values()):
             total += task.get("row_count", 0)
             self.create_transfer_log(task["target_table_object"])
 
@@ -669,7 +727,7 @@ fi
             fully_copied = 0
             self._tables_to_exclude = list()
             self._count_of_failed_tables = 0
-            for task in self._working_set.values():
+            for task in list(self._working_set.values()):
                 info = succeeded_tasks.get(task["target_schema"]+"."+task["target_table"], None)
                 row_count = task.get("row_count", 0)
                 if info:
