@@ -1,35 +1,42 @@
-# Copyright (c) 2013, 2014, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2013, 2019, Oracle and/or its affiliates. All rights reserved.
 #
-# This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License as
-# published by the Free Software Foundation; version 2 of the
-# License.
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License, version 2.0,
+# as published by the Free Software Foundation.
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
+# This program is also distributed with certain software (including
+# but not limited to OpenSSL) that is licensed under separate terms, as
+# designated in a particular file or component or in included license
+# documentation.  The authors of MySQL hereby grant you an additional
+# permission to link the program and your derivative works with the
+# separately licensed software that they have included with MySQL.
+# This program is distributed in the hope that it will be useful,  but
+# WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+# the GNU General Public License, version 2.0, for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-# 02110-1301  USA
-
+# along with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 
 import mforms
 import grt
-
+import sys
 from workbench.log import log_error
 
 from sqlide_catalogman_ext import MaintenanceResultForm
 from sqlide_catalogman_ext import ObjectManager
 from sqlide_catalogman_ext import TriggerManager
 from sqlide_catalogman_ext import ColumnManager
-from mforms import IconStringColumnType, StringColumnType, IntegerColumnType
+from mforms import IconStringColumnType, StringColumnType, LongIntegerColumnType
 from wb_admin_utils import make_panel_header
 from workbench.utils import human_size, Version
+from wb_common import to_unicode
 
-
+def make_title(t):
+    l = mforms.newLabel(t)
+    l.set_style(mforms.BoldStyle)
+    return l
 
 def show_table_inspector(editor, selection, page = None):
     for schema, table in selection:
@@ -38,7 +45,7 @@ def show_table_inspector(editor, selection, page = None):
         dpoint = mforms.fromgrt(editor.dockingPoint)
         dpoint.dock_view(tinspect, "", 0)
         dpoint.select_view(tinspect)
-        tinspect.set_title("%s.%s" % (schema, table))
+        tinspect.set_title("%s.%s" % (to_unicode(schema), to_unicode(table)))
         if page is not None:
             tinspect.switch_to_page(page)
 
@@ -77,6 +84,7 @@ class TableInfoPanel(mforms.Box):
         self.set_release_on_add()
         
         self.editor = editor
+        self.target_version = Version.fromgrt(self.editor.serverVersion)
         
         self.table = mforms.newTable()
         offset = 2 if self.i_s_innodb_available() else 0
@@ -85,17 +93,12 @@ class TableInfoPanel(mforms.Box):
         self.table.set_row_spacing(8)
         self.table.set_column_spacing(8)
 
-        def make_title(t):
-            l = mforms.newLabel(t)
-            l.set_style(mforms.BoldStyle)
-            return l
-
         self.panel_header_box = mforms.newBox(True)
         self.panel_header_box.set_padding(10)
 
         self._table_engine = None
         
-        self.add(self.panel_header_box,False, False)
+        self.add(self.panel_header_box,False, True)
 
 
         self.table.add(make_title("Table Details"), 0, 2, 0, 1, mforms.HFillFlag)
@@ -190,6 +193,9 @@ class TableInfoPanel(mforms.Box):
         self.table_comment = mforms.newLabel("")
         self.table_comment.set_style(mforms.BoldStyle)
         self.table_comment.set_wrap_text(True)
+        if sys.platform.lower() == "win32": # We need this so Win will recompute the dimensions.
+            self.table_comment.set_size(1, -1)
+
         self.table.add(self.table_comment,                      1, 2, 18 + offset, 19 + offset, mforms.HFillFlag|mforms.HExpandFlag)
         
         scroll = mforms.ScrollPanel()
@@ -221,27 +227,29 @@ class TableInfoPanel(mforms.Box):
         table.add(self.analyze_btn,                                                     1, 2, 0, 1, mforms.HFillFlag)
         table.add(mforms.newLabel(" to update it."),                              2, 3, 0, 1, mforms.HFillFlag)
         
-        bbox.add(table, False, False)
+        bbox.add(table, False, True)
         
-        self.add(bbox, False, False)
+        self.add(bbox, False, True)
         
     def get_table_engine(self):
         return self._table_engine
 
     def analyze_table(self):
-        result = self.editor.executeManagementQuery("ANALYZE TABLE %s.%s" % (self._schema, self._table), 1)
+        result = self.editor.executeManagementQuery("ANALYZE TABLE `%s`.`%s`" % (self._schema, self._table), 1)
         form = MaintenanceResultForm(result, False)
         form.set_title("ANALYZE TABLE")
         form.run()
         self.refresh()
         
     def i_s_innodb_available(self):
-        return self.editor.serverVersion.majorNumber == 5 and self.editor.serverVersion.minorNumber == 6
+          return  self.target_version.is_supported_mysql_version_at_least(5, 6)
+
+        
 
     def refresh(self):
         try:
             rset = self.editor.executeManagementQuery("select * from information_schema.tables WHERE table_schema = '%s' AND table_name = '%s'" % (self._schema, self._table), 0)
-        except grt.DBError, e:
+        except grt.DBError as e:
             log_error("select * from information_schema.tables WHERE table_schema = '%s' AND table_name = '%s': %s\n" % (self._schema, self._table, e))
             rset = None
             
@@ -269,12 +277,12 @@ class TableInfoPanel(mforms.Box):
                 self.index_length.set_text(human_size(int(column_values['index_length'])))
                 self.data_free.set_text(human_size(int(column_values['data_free'])))
                 self.max_data_length.set_text(human_size(int(column_values['max_data_length'])))
-            except Exception, e:
+            except Exception as e:
                 log_error("Error displaying table info for %s.%s: %s\n" % (self._schema, self._table, e))
 
         try:
             rset = self.editor.executeManagementQuery("select count(*) column_count from information_schema.columns WHERE table_schema = '%s' and table_name = '%s'" % (self._schema, self._table), 0)
-        except grt.DBError, e:
+        except grt.DBError as e:
             log_error("select count(*) column_count from information_schema.columns WHERE table_schema = '%s' and table_name = '%s': %s\n" % (self._schema, self._table, e))
             rset = None
 
@@ -284,17 +292,25 @@ class TableInfoPanel(mforms.Box):
                 self.column_count.set_text(rset.stringFieldValueByName("column_count"));
             
         if self.i_s_innodb_available():
+            if self.target_version.is_supported_mysql_version_at_least(8, 0):
+                query = "SELECT @@datadir datadir,sd.path FROM information_schema.INNODB_TABLES st JOIN information_schema.innodb_datafiles sd USING(space) WHERE st.name = '%s/%s'" % (self._schema, self._table)
+            else:
+                query = "SELECT @@datadir datadir,st.FILE_FORMAT,sd.path FROM information_schema.INNODB_SYS_TABLES st JOIN information_schema.innodb_sys_datafiles sd USING(space) WHERE st.name = '%s/%s'" % (self._schema, self._table)
             try:
-                rset = self.editor.executeManagementQuery("SELECT @@datadir datadir,st.FILE_FORMAT,sd.path FROM information_schema.INNODB_SYS_TABLES st JOIN information_schema.innodb_sys_datafiles sd USING(space) WHERE st.name = '%s/%s'" % (self._schema, self._table), 0)
-            except grt.DBError, e:
-                log_error("SELECT @@datadir datadir,st.FILE_FORMAT,sd.path FROM information_schema.INNODB_SYS_TABLES st JOIN information_schema.innodb_sys_datafiles sd USING(space) WHERE st.name = '%s/%s'': %s\n" % (self._schema, self._table, e))
+                rset = self.editor.executeManagementQuery(query, 0)
+            except grt.DBError as e:
+                log_error("%s': %s\n" % (query, e))
                 rset = None
-
             if rset:
                 ok = rset.goToFirstRow()
                 if ok:
-                    self.file_format.set_text(rset.stringFieldValueByName("FILE_FORMAT"))
-                    data_path = rset.stringFieldValueByName("path")
+                    if self.target_version.is_supported_mysql_version_at_least(8, 0):
+                            self.file_format.set_text("")
+                            data_path = rset.stringFieldValueByName("PATH")
+                    else:
+                            self.file_format.set_text(rset.stringFieldValueByName("FILE_FORMAT"))
+                            data_path = rset.stringFieldValueByName("path")
+
                     if data_path[:1] == ".":
                         self.data_path.set_text("%s%s" %(rset.stringFieldValueByName("datadir"), data_path[2:]))
                     else:
@@ -304,11 +320,52 @@ class TableInfoPanel(mforms.Box):
         self._schema = schema
         self._table = table
 
-        self.panel_header_box.add(make_panel_header("db.Table.32x32.png", self.editor.connection.name, "%s.%s" % (schema, table)), False, False)
+        self.panel_header_box.add(make_panel_header("db.Table.32x32.png", self.editor.connection.name, "%s.%s" % (schema, table)), False, True)
 
         self.refresh()
 
+class TableDDL(mforms.Box):
+    caption = "DDL"
+    node_name = "structure"
+    def __init__(self, editor):
+        mforms.Box.__init__(self, False)
+        self.set_managed()
+        self.set_release_on_add()
 
+        self.editor = editor
+        self.set_spacing(15)
+        self.set_padding(15)
+        self.title_box = mforms.newBox(False)
+        self.title_box.set_spacing(1)
+
+        self.add(self.title_box, False, True)
+
+        self.code_editor = mforms.CodeEditor()
+        self.code_editor.set_language(mforms.LanguageMySQL)
+        self.code_editor.set_managed()
+        self.code_editor.set_read_only(True)
+        self.code_editor.set_release_on_add()
+        self.add(self.code_editor, True, True)
+
+    def refresh(self):
+        try:
+            rset = self.editor.executeManagementQuery("show create table `%s`.`%s`" % (self._schema, self._table), 0)
+        except grt.DBError as e:
+            log_error("show create table `%s`.`%s` : %s\n" % (self._schema, self._table, e))
+            rset = None
+
+        if rset:
+            ok = rset.goToFirstRow()
+            if ok:
+                self.code_editor.set_read_only(False)
+                self.code_editor.set_value(rset.stringFieldValue(1));
+                self.code_editor.set_read_only(True)
+
+    def show_table(self, schema, table):
+        self._schema = schema
+        self._table = table
+        self.title_box.add(make_title("DDL for %s.%s" % (self._schema, self._table)), False, True)
+        self.refresh()
 
 class CreateIndexForm(mforms.Form):
     def __init__(self, owner, editor, schema, table, columns, engine):
@@ -345,7 +402,7 @@ class CreateIndexForm(mforms.Form):
         self.kind = mforms.newSelector()
         self.kind.add_items(["Non-Unique", "Unique", "FullText", "Spatial"])
         hbox.add(self.kind, False, True)
-        table.add(hbox, 1, 2, 0, 1, mforms.HFillFlag|mforms.HExpandFlag)
+        table.add(hbox, 1, 2, 0, 1, mforms.VFillFlag|mforms.HFillFlag|mforms.HExpandFlag)
 
         if self._engine in ["memory", "heap","ndb"]:
             table.add(mforms.newLabel("Type:", True), 0, 1, 1, 2, mforms.HFillFlag)
@@ -356,7 +413,7 @@ class CreateIndexForm(mforms.Form):
         l = mforms.newLabel("Columns:")
         l.set_text_align(mforms.TopRight)
         table.add(l, 0, 1, 2, 3, mforms.HFillFlag|mforms.VFillFlag)
-        self.columns = mforms.newTreeNodeView(mforms.TreeFlatList|mforms.TreeAltRowColors|mforms.TreeShowColumnLines)
+        self.columns = mforms.newTreeView(mforms.TreeFlatList|mforms.TreeAltRowColors|mforms.TreeShowColumnLines)
         self.columns.add_column(mforms.StringColumnType, "Column", 200, False)
         self.columns.add_column(mforms.StringColumnType, "Length", 60, True)
         #        self.columns.add_column(mforms.CheckColumnType, "Order", 50, False) # ignored by server
@@ -367,7 +424,7 @@ class CreateIndexForm(mforms.Form):
         tbl.set_column_count(2)
         tbl.set_row_spacing(2)
         tbl.set_column_spacing(4)
-        tbl.add(self.columns, 0, 1, 0, 3, mforms.HFillFlag|mforms.VFillFlag|mforms.HExpandFlag)
+        tbl.add(self.columns, 0, 1, 0, 3, mforms.HFillFlag|mforms.VFillFlag|mforms.HExpandFlag|mforms.VExpandFlag)
         self.move_up = mforms.newButton()
         self.move_up.set_text("\xe2\x96\xb2")
         self.move_up.add_clicked_callback(self.move_row_up)
@@ -376,10 +433,10 @@ class CreateIndexForm(mforms.Form):
         self.move_down.set_text("\xe2\x96\xbc")
         self.move_down.add_clicked_callback(self.move_row_down)
         self.move_down.enable_internal_padding(False)
-        tbl.add(self.move_up, 1, 2, 0, 1, mforms.HFillFlag)
-        tbl.add(self.move_down, 1, 2, 1, 2, mforms.HFillFlag)
-        tbl.add(mforms.newLabel(""), 1, 2, 2, 3, mforms.HFillFlag|mforms.VExpandFlag)
-        table.add(tbl, 1, 2, 2, 3, mforms.HFillFlag)
+        tbl.add(self.move_up, 1, 2, 0, 1, mforms.VFillFlag|mforms.HFillFlag)
+        tbl.add(self.move_down, 1, 2, 1, 2, mforms.VFillFlag|mforms.HFillFlag)
+        tbl.add(mforms.newLabel(""), 1, 2, 2, 3, mforms.VFillFlag|mforms.HFillFlag|mforms.VExpandFlag)
+        table.add(tbl, 1, 2, 2, 3, mforms.VFillFlag|mforms.HFillFlag)
 
         l = mforms.newLabel("Comments:")
         l.set_text_align(mforms.TopRight)
@@ -424,7 +481,7 @@ class CreateIndexForm(mforms.Form):
         mforms.Utilities.add_end_ok_cancel_buttons(bbox, self.ok, self.cancel)
         content.add_end(bbox, False, True)
 
-        self.set_size(550, -1)
+        self.set_size(550, 400)
         self.center()
 
     def move_row_up(self):
@@ -483,7 +540,7 @@ class CreateIndexForm(mforms.Form):
             try:
                 self._editor.executeManagementCommand(sql, 1)
                 return True
-            except grt.DBError, e:
+            except grt.DBError as e:
                 mforms.Utilities.show_error("Create Index",
                                             "Error creating index.\n%s" % e.args[0],
                                             "OK", "", "")
@@ -514,19 +571,17 @@ class TableIndexInfoPanel(mforms.Box):
         table.set_column_spacing(8)
         self.add(table, False, True)
 
-        def make_title(t):
-            l = mforms.newLabel(t)
-            l.set_style(mforms.BoldStyle)
-            return l
-
         table.add(make_title("Indexes in Table"), 0, 1, 0, 1, mforms.HFillFlag)
-        self.index_list = mforms.newTreeNodeView(mforms.TreeFlatList|mforms.TreeAltRowColors|mforms.TreeShowColumnLines)
+        self.index_list = mforms.newTreeView(mforms.TreeFlatList|mforms.TreeAltRowColors|mforms.TreeShowColumnLines)
+        if self.target_version.is_supported_mysql_version_at_least(8, 0, 0):
+            self.index_list.add_column(mforms.CheckColumnType, "Visible", 50, True)
         self.index_list.add_column(mforms.IconStringColumnType, "Key", 140, False)
         self.index_list.add_column(mforms.StringColumnType, "Type", 80, False)
         self.index_list.add_column(mforms.StringColumnType, "Unique", 40, False)
         self.index_list.add_column(mforms.StringColumnType, "Columns", 200, False)
         self.index_list.end_columns()
         self.index_list.add_changed_callback(self.index_selected)
+        self.index_list.set_cell_edited_callback(self.edit_index)
         self.index_list.set_size(450, -1)
         table.add(self.index_list, 0, 1, 1, 2, mforms.HFillFlag|mforms.VFillFlag)
 
@@ -537,7 +592,7 @@ class TableIndexInfoPanel(mforms.Box):
         self.drop_index.set_enabled(False)
         self.drop_index.add_clicked_callback(self.do_drop_index)
         dhbox.add_end(self.drop_index, False, True)
-        table.add(dhbox, 1, 3, 0, 1, mforms.HFillFlag|mforms.HExpandFlag)
+        table.add(dhbox, 1, 3, 0, 1, mforms.HFillFlag|mforms.HExpandFlag|mforms.VFillFlag)
         
         self.info = mforms.newTable()
         table.add(self.info, 1, 3, 1, 2, mforms.HFillFlag|mforms.HExpandFlag|mforms.VFillFlag)
@@ -599,7 +654,7 @@ class TableIndexInfoPanel(mforms.Box):
 
         table.add(make_title("Columns in table"), 0, 2, 0, 1, mforms.HFillFlag|mforms.HExpandFlag)
 
-        self.column_list = mforms.newTreeNodeView(mforms.TreeFlatList|mforms.TreeAltRowColors|mforms.TreeShowColumnLines)
+        self.column_list = mforms.newTreeView(mforms.TreeFlatList|mforms.TreeAltRowColors|mforms.TreeShowColumnLines)
         self.column_list.add_column(mforms.IconStringColumnType, "Column", 150, False)
         self.column_list.add_column(mforms.StringColumnType, "Type", 150, False)
         self.column_list.add_column(mforms.StringColumnType, "Nullable", 50, False)
@@ -615,19 +670,17 @@ class TableIndexInfoPanel(mforms.Box):
         hbox.add_end(self.create_index, False, True)
         self.add(hbox, False, True)
 
-
     def do_drop_index(self):
         node = self.index_list.get_selected_node()
         if node:
-            index = node.get_string(0)
+            index = node.get_string(1) if self.target_version.is_supported_mysql_version_at_least(8, 0, 0) else node.get_string(0)
             if mforms.Utilities.show_message("Drop Index", "Drop index `%s` from table `%s`.`%s`?" % (index, self._schema, self._table), "Drop", "Cancel", "") == mforms.ResultOk:
                 try:
                     self.editor.executeManagementCommand("DROP INDEX `%s` ON `%s`.`%s`" % (index, self._schema, self._table), 1)
                     self.refresh()
-                except grt.DBError, e:
+                except grt.DBError as e:
                     mforms.Utilities.show_error("Drop Index", "Error dropping index.\n%s" % e.args[0], "OK", "", "")
 
-
     def do_create_index(self):
         cols = []
         for node in self.column_list.get_selection():
@@ -636,7 +689,16 @@ class TableIndexInfoPanel(mforms.Box):
             form = CreateIndexForm(self, self.editor, self._schema, self._table, cols, self.get_table_engine() if self.get_table_engine else None)
             if form.run():
                 self.refresh()
+        else:
+            mforms.Utilities.show_warning("Create Index","You have to select at least one column.\n", "OK", "", "")
 
+    def edit_index(self, node, column, value):
+        if self.target_version.is_supported_mysql_version_at_least(8, 0, 0):
+            index = node.get_string(1)
+            sql = "ALTER TABLE `%s`.`%s` ALTER INDEX `%s` %s" % (self._schema, self._table, index, "INVISIBLE" if node.get_bool(0) is True else "VISIBLE")
+            if mforms.Utilities.show_message("Alter Index", "Do you really want to %s ?" % sql, "Yes", "Cancel", "") == mforms.ResultOk:
+                self.editor.executeManagementCommand(sql, 1)
+                node.set_bool(0, False if node.get_bool(0) is True else True)
 
     def index_selected(self):
         node = self.index_list.get_selected_node()
@@ -684,14 +746,14 @@ class TableIndexInfoPanel(mforms.Box):
         if table:
             try:
                 rset = self.editor.executeManagementQuery("SHOW INDEX FROM `%s`.`%s`" % (schema, table), 0)
-            except grt.DBError, e:
+            except grt.DBError as e:
                 log_error("Cannot execute SHOW INDEX FROM `%s`.`%s`: %s\n" % (schema, table, e))
                 rset = None
 
             if self.target_version.is_supported_mysql_version_at_least(Version.fromstr("5.6")):
-                index_rs_columns = range(13)
+                index_rs_columns = list(range(13))
             else:
-                index_rs_columns = range(12)
+                index_rs_columns = list(range(12))
             column_rs_columns = [3, 4, 5, 7]
             for i in column_rs_columns:
                 index_rs_columns.remove(i)
@@ -701,22 +763,34 @@ class TableIndexInfoPanel(mforms.Box):
                 curname = None
                 itype = None
                 non_unique = None
+                is_visible = True
                 columns = []
                 while ok:
                     name = rset.stringFieldValue(2)
                     if name != curname:
                         if columns:
                             node = self.index_list.add_node()
-                            node.set_icon_path(0, index_icon)
-                            node.set_string(0, curname)
-                            node.set_string(1, itype)
-                            node.set_string(2, "YES" if non_unique != "1" else "NO")
-                            node.set_string(3, ", ".join([c[1] for c in columns]))
+                            if self.target_version.is_supported_mysql_version_at_least(8, 0, 0):
+                                node.set_bool(0, is_visible)
+                                node.set_icon_path(1, index_icon)
+                                node.set_string(1, curname)
+                                node.set_string(2, itype)
+                                node.set_string(3, "YES" if non_unique != "1" else "NO")
+                                node.set_string(4, ", ".join([c[1] for c in columns]))
+                            else:
+                                node.set_icon_path(0, index_icon)
+                                node.set_string(0, curname)
+                                node.set_string(1, itype)
+                                node.set_string(2, "YES" if non_unique != "1" else "NO")
+                                node.set_string(3, ", ".join([c[1] for c in columns]))
                         columns = []
                         self.index_info.append(([rset.stringFieldValue(i) for i in index_rs_columns], columns))
                         curname = name
                         itype = rset.stringFieldValue(10)
                         non_unique = rset.stringFieldValue(1)
+                        is_visible = True
+                        if self.target_version.is_supported_mysql_version_at_least(8, 0, 0):
+                            is_visible = rset.stringFieldValue(13) == "YES"
 
                     cname = rset.stringFieldValue(4)
                     if cname not in column_to_index:
@@ -725,16 +799,25 @@ class TableIndexInfoPanel(mforms.Box):
                         column_to_index[cname].append(name)
                     columns.append([rset.stringFieldValue(i) for i in column_rs_columns])
                     ok = rset.nextRow()
+
                 if columns:
                     node = self.index_list.add_node()
-                    node.set_icon_path(0, index_icon)
-                    node.set_string(0, curname)
-                    node.set_string(1, itype)
-                    node.set_string(2, "YES" if non_unique != "1" else "NO")
-                    node.set_string(3, ", ".join([c[1] for c in columns]))
+                    if self.target_version.is_supported_mysql_version_at_least(8, 0, 0):
+                        node.set_bool(0, is_visible)
+                        node.set_icon_path(1, index_icon)
+                        node.set_string(1, curname)
+                        node.set_string(2, itype)
+                        node.set_string(3, "YES" if non_unique != "1" else "NO")
+                        node.set_string(4, ", ".join([c[1] for c in columns]))
+                    else:
+                        node.set_icon_path(0, index_icon)
+                        node.set_string(0, curname)
+                        node.set_string(1, itype)
+                        node.set_string(2, "YES" if non_unique != "1" else "NO")
+                        node.set_string(3, ", ".join([c[1] for c in columns]))
             try:
                 rset = self.editor.executeManagementQuery("SHOW COLUMNS FROM `%s`.`%s`" % (schema, table), 0)
-            except grt.DBError, e:
+            except grt.DBError as e:
                 log_error("Cannot execute SHOW COLUMNS FROM `%s`.`%s`: %s\n" % (schema, table, e))
                 rset = None
 
@@ -840,18 +923,18 @@ class PartitionManager(TableManDefs, ObjectManager):
     icon_column = 0
     columns = [("partition_name", IconStringColumnType, "Name", 200, None),
                ("subpartition_name", StringColumnType, "Subpartiton Name", 100, None),
-               ("partition_ordinal_position", IntegerColumnType, "Ordinal Pos", 100, None),
-               ("subpartition_ordinal_position", IntegerColumnType, "Subpartiton Ordinal Pos", 100, None),
+               ("partition_ordinal_position", LongIntegerColumnType, "Ordinal Pos", 100, None),
+               ("subpartition_ordinal_position", LongIntegerColumnType, "Subpartiton Ordinal Pos", 100, None),
                ("partition_method", StringColumnType, "Partition Method", 100, None),
                ("subpartition_method", StringColumnType, "Subpartition Method", 100, None),
                ("partition_expression", StringColumnType, "Partition expression", 100, None),
                ("subpartition_expression", StringColumnType, "Subpartition expression", 100, None),
                ("partition_description", StringColumnType, "Partition description", 100, None),
-               ("table_rows", IntegerColumnType, "Table rows", 100, None),
-               ("avg_row_length", IntegerColumnType, "AVG row length", 100, None),
-               ("data_length", IntegerColumnType, "Data length", 100, None),
-               ("max_data_length", IntegerColumnType, "max data length", 100, None),
-               ("index_length", IntegerColumnType, "Index length", 100, None),
+               ("table_rows", LongIntegerColumnType, "Table rows", 100, None),
+               ("avg_row_length", LongIntegerColumnType, "AVG row length", 100, None),
+               ("data_length", LongIntegerColumnType, "Data length", 100, None),
+               ("max_data_length", LongIntegerColumnType, "max data length", 100, None),
+               ("index_length", LongIntegerColumnType, "Index length", 100, None),
                ("create_time", StringColumnType, "Create time", 150, None),
                ("update_time", StringColumnType, "Update time", 150, None),
                ("check_time", StringColumnType, "Check time", 150, None)]
@@ -883,7 +966,7 @@ class GrantsTableManager(TableManDefs, ObjectManager):
         query = "show columns from `mysql`.`tables_priv` like 'table_priv'"
         try:
             rset = self.editor.executeManagementQuery(query, 0)
-        except grt.DBError, e:
+        except grt.DBError as e:
             if e.args[1] == 1044 or e.args[1] == 1142:
                 
                 self.show_error("Access Error", "The current user does not have enough privileges to execute %s.\n\n%s" % (query, e.args[0]))
@@ -972,7 +1055,7 @@ class GrantsColumnManager(TableManDefs, ObjectManager):
         query = "show columns from `mysql`.`columns_priv` like 'Column_priv'"
         try:
             rset = self.editor.executeManagementQuery(query, 0)
-        except grt.DBError, e:
+        except grt.DBError as e:
             if e.args[1] == 1044 or e.args[1] == 1142:
                 self.show_error("Access Error", "The current user does not have enough privileges to execute %s.\n\n%s" % (query, e.args[0]))
             else:
@@ -1027,11 +1110,6 @@ class GrantsManager(TableManDefs, mforms.Box):
         self.set_managed()
         self.set_release_on_add()
 
-        def make_title(t):
-            l = mforms.newLabel(t)
-            l.set_style(mforms.BoldStyle)
-            return l
-
         self.editor = editor
 
         self.set_padding(8)
@@ -1075,7 +1153,7 @@ class TableInspector(mforms.AppView):
         self.tab_list = {}
         self.pages = []
 
-        mforms.AppView.__init__(self, False, "TableInspector", False)
+        mforms.AppView.__init__(self, False, "Table Inspector", "TableInspector", False)
 
         self.set_managed()
         self.set_release_on_add()
@@ -1083,7 +1161,7 @@ class TableInspector(mforms.AppView):
         self.tab = mforms.newTabView()
         self.add(self.tab, True, True)
 
-        tabs = [TableInfoPanel, TableColumnManager, TableIndexInfoPanel, TableTriggerManager, ConstraintManager, PartitionManager, GrantsManager]
+        tabs = [TableInfoPanel, TableColumnManager, TableIndexInfoPanel, TableTriggerManager, ConstraintManager, PartitionManager, GrantsManager, TableDDL]
 
         i =0
         for Tab in tabs:
@@ -1101,11 +1179,12 @@ class TableInspector(mforms.AppView):
 
     def show_table(self, schema, table):
         for tab in self.pages:
-#             try:
-            tab.show_table(schema, table)
-#             except:
-#                 print "some error"
-#                 continue # If user will launch table inspector on Information or Performance Schema, there can be some problems, let's catch those.
+            try:
+                tab.show_table(schema, table)
+            except Exception:
+                import traceback
+                log_error("Error initializing tab %s: %s\n" % (tab.node_name, traceback.format_exc()))
+                continue # If user will launch table inspector on Information or Performance Schema, there can be some problems, let's catch those.
         #After each tab is loaded we can make a ptr to the get_table_engine method
         self.pages[self.tab_list["indexes"]].get_table_engine = self.pages[self.tab_list["informations"]].get_table_engine
 
